@@ -13,6 +13,40 @@ class BalanceComp(ImplicitComponent):
     """
     A simple equation balance for solving implicit equations.
 
+    Parameters
+    ----------
+    name : str
+        The name of the state variable to be created.
+    eq_units : str or None
+        Units for the left-hand-side and right-hand-side of the equation to be balanced.
+    lhs_name : str or None
+        Optional name for the LHS variable associated with the implicit state variable.  If
+        None, the default will be used:  'lhs:{name}'.
+    rhs_name : str or None
+        Optional name for the RHS variable associated with the implicit state variable.  If
+        None, the default will be used:  'rhs:{name}'.
+    rhs_val : int, float, or np.array
+        Default value for the RHS of the given state.  Must be compatible
+        with the shape (optionally) given by the val or shape option in kwargs.
+    use_mult : bool
+        Specifies whether the LHS multiplier is to be used.  If True, then an additional
+        input `mult_name` is created, with the default value given by `mult_val`, that
+        multiplies lhs.  Default is False.
+    mult_name : str or None
+        Optional name for the LHS multiplier variable associated with the implicit state
+        variable. If None, the default will be used: 'mult:{name}'.
+    mult_val : int, float, or np.array
+        Default value for the LHS multiplier of the given state.  Must be compatible
+        with the shape (optionally) given by the val or shape option in kwargs.
+    normalize : bool
+        Specifies whether or not the resulting residual should be normalized by a quadratic
+        function of the RHS.
+    val : float, int, or np.ndarray
+        Set initial value for the state.
+    **kwargs : dict
+        Additional arguments to be passed for the creation of the implicit state variable.
+        (see `add_output` method).
+
     Attributes
     ----------
     _state_vars : dict
@@ -97,40 +131,6 @@ class BalanceComp(ImplicitComponent):
             prob.setup()
             prob.set_val('exec.x', 2)
             prob.run_model()
-
-        Parameters
-        ----------
-        name : str
-            The name of the state variable to be created.
-        eq_units : str or None
-            Units for the left-hand-side and right-hand-side of the equation to be balanced.
-        lhs_name : str or None
-            Optional name for the LHS variable associated with the implicit state variable.  If
-            None, the default will be used:  'lhs:{name}'.
-        rhs_name : str or None
-            Optional name for the RHS variable associated with the implicit state variable.  If
-            None, the default will be used:  'rhs:{name}'.
-        rhs_val : int, float, or np.array
-            Default value for the RHS of the given state.  Must be compatible
-            with the shape (optionally) given by the val or shape option in kwargs.
-        use_mult : bool
-            Specifies whether the LHS multiplier is to be used.  If True, then an additional
-            input `mult_name` is created, with the default value given by `mult_val`, that
-            multiplies lhs.  Default is False.
-        mult_name : str or None
-            Optional name for the LHS multiplier variable associated with the implicit state
-            variable. If None, the default will be used: 'mult:{name}'.
-        mult_val : int, float, or np.array
-            Default value for the LHS multiplier of the given state.  Must be compatible
-            with the shape (optionally) given by the val or shape option in kwargs.
-        normalize : bool
-            Specifies whether or not the resulting residual should be normalized by a quadratic
-            function of the RHS.
-        val : float, int, or np.ndarray
-            Set initial value for the state.
-        **kwargs : dict
-            Additional arguments to be passed for the creation of the implicit state variable.
-            (see `add_output` method).
         """
         if 'guess_func' in kwargs:
             super().__init__(guess_func=kwargs['guess_func'])
@@ -153,37 +153,31 @@ class BalanceComp(ImplicitComponent):
         Parameters
         ----------
         inputs : Vector
-            unscaled, dimensional input variables read via inputs[key]
+            Unscaled, dimensional input variables read via inputs[key].
         outputs : Vector
-            unscaled, dimensional output variables read via outputs[key]
+            Unscaled, dimensional output variables read via outputs[key].
         residuals : Vector
-            unscaled, dimensional residuals written to via residuals[key]
+            Unscaled, dimensional residuals written to via residuals[key].
         """
-        if inputs._under_complex_step:
-            self._scale_factor = self._scale_factor.astype(complex)
-        else:
-            self._scale_factor = self._scale_factor.real
-
         for name, options in self._state_vars.items():
             lhs = inputs[options['lhs_name']]
             rhs = inputs[options['rhs_name']]
+            _scale_factor = np.ones((rhs.shape))
 
             if options['normalize']:
                 # Indices where the rhs is near zero or not near zero
-                idxs_nz = np.where(cs_safe.abs(rhs) < 2)[0]
-                idxs_nnz = np.where(cs_safe.abs(rhs) >= 2)[0]
+                idxs_nz = np.where(cs_safe.abs(rhs) < 2)
+                idxs_nnz = np.where(cs_safe.abs(rhs) >= 2)
 
                 # Compute scaling factors
                 # scale factor that normalizes by the rhs, except near 0
-                self._scale_factor[idxs_nnz] = 1.0 / cs_safe.abs(rhs[idxs_nnz])
-                self._scale_factor[idxs_nz] = 1.0 / (.25 * rhs[idxs_nz] ** 2 + 1)
-            else:
-                self._scale_factor[:] = 1.0
+                _scale_factor[idxs_nnz] = 1.0 / cs_safe.abs(rhs[idxs_nnz])
+                _scale_factor[idxs_nz] = 1.0 / (.25 * rhs[idxs_nz] ** 2 + 1)
 
             if options['use_mult']:
-                residuals[name] = (inputs[options['mult_name']] * lhs - rhs) * self._scale_factor
+                residuals[name] = (inputs[options['mult_name']] * lhs - rhs) * _scale_factor
             else:
-                residuals[name] = (lhs - rhs) * self._scale_factor
+                residuals[name] = (lhs - rhs) * _scale_factor
 
     def linearize(self, inputs, outputs, jacobian):
         """
@@ -192,17 +186,12 @@ class BalanceComp(ImplicitComponent):
         Parameters
         ----------
         inputs : Vector
-            unscaled, dimensional input variables read via inputs[key]
+            Unscaled, dimensional input variables read via inputs[key].
         outputs : Vector
-            unscaled, dimensional output variables read via outputs[key]
+            Unscaled, dimensional output variables read via outputs[key].
         jacobian : Jacobian
-            sub-jac components written to jacobian[output_name, input_name]
+            Sub-jac components written to jacobian[output_name, input_name].
         """
-        if inputs._under_complex_step:
-            self._dscale_drhs = self._dscale_drhs.astype(complex)
-        else:
-            self._dscale_drhs = self._dscale_drhs.real
-
         for name, options in self._state_vars.items():
             lhs_name = options['lhs_name']
             rhs_name = options['rhs_name']
@@ -210,37 +199,37 @@ class BalanceComp(ImplicitComponent):
             lhs = inputs[lhs_name]
             rhs = inputs[rhs_name]
 
+            _scale_factor = np.ones((rhs.shape))
+            _dscale_drhs = np.zeros((rhs.shape))
+
             if options['normalize']:
                 # Indices where the rhs is near zero or not near zero
                 idxs_nz = np.where(cs_safe.abs(rhs) < 2)[0]
                 idxs_nnz = np.where(cs_safe.abs(rhs) >= 2)[0]
 
                 # scale factor that normalizes by the rhs, except near 0
-                self._scale_factor[idxs_nnz] = 1.0 / cs_safe.abs(rhs[idxs_nnz])
-                self._scale_factor[idxs_nz] = 1.0 / (.25 * rhs[idxs_nz] ** 2 + 1)
+                _scale_factor[idxs_nnz] = 1.0 / cs_safe.abs(rhs[idxs_nnz])
+                _scale_factor[idxs_nz] = 1.0 / (.25 * rhs[idxs_nz] ** 2 + 1)
 
-                self._dscale_drhs[idxs_nnz] = -np.sign(rhs[idxs_nnz]) / rhs[idxs_nnz]**2
-                self._dscale_drhs[idxs_nz] = -.5 * rhs[idxs_nz] / (.25 * rhs[idxs_nz] ** 2 + 1) ** 2
-            else:
-                self._scale_factor[:] = 1.0
-                self._dscale_drhs[:] = 0.0
+                _dscale_drhs[idxs_nnz] = -np.sign(rhs[idxs_nnz]) / rhs[idxs_nnz]**2
+                _dscale_drhs[idxs_nz] = -.5 * rhs[idxs_nz] / (.25 * rhs[idxs_nz] ** 2 + 1) ** 2
 
             if options['use_mult']:
                 mult_name = options['mult_name']
                 mult = inputs[mult_name]
 
                 # Partials of residual wrt mult
-                deriv = lhs * self._scale_factor
+                deriv = lhs * _scale_factor
                 jacobian[name, mult_name] = deriv.flatten()
             else:
                 mult = 1.0
 
             # Partials of residual wrt rhs
-            deriv = (mult * lhs - rhs) * self._dscale_drhs - self._scale_factor
+            deriv = (mult * lhs - rhs) * _dscale_drhs - _scale_factor
             jacobian[name, rhs_name] = deriv.flatten()
 
             # Partials of residual wrt lhs
-            deriv = mult * self._scale_factor
+            deriv = mult * _scale_factor
             jacobian[name, lhs_name] = deriv.flatten()
 
     def guess_nonlinear(self, inputs, outputs, residuals):
@@ -252,11 +241,11 @@ class BalanceComp(ImplicitComponent):
         Parameters
         ----------
         inputs : Vector
-            unscaled, dimensional input variables read via inputs[key]
+            Unscaled, dimensional input variables read via inputs[key].
         outputs : Vector
-            unscaled, dimensional output variables read via outputs[key]
+            Unscaled, dimensional output variables read via outputs[key].
         residuals : Vector
-            unscaled, dimensional residuals written to via residuals[key]
+            Unscaled, dimensional residuals written to via residuals[key].
         """
         if self.options['guess_func'] is not None:
             self.options['guess_func'](inputs, outputs, residuals)
@@ -347,9 +336,6 @@ class BalanceComp(ImplicitComponent):
                            val=options['mult_val'] * np.ones(shape),
                            units=None)
 
-        self._scale_factor = np.ones(shape)
-        self._dscale_drhs = np.ones(shape)
-
         ar = np.arange(np.prod(shape))
         self.declare_partials(of=name, wrt=options['lhs_name'], rows=ar, cols=ar, val=1.0)
         self.declare_partials(of=name, wrt=options['rhs_name'], rows=ar, cols=ar, val=1.0)
