@@ -6,16 +6,17 @@ implementations.
 """
 import numpy as np
 
-from openmdao.components.interp_util.interp_akima import InterpAkima, InterpAkima1D
+from openmdao.components.interp_util.interp_akima import InterpAkima, Interp1DAkima
 from openmdao.components.interp_util.interp_bsplines import InterpBSplines
 from openmdao.components.interp_util.interp_cubic import InterpCubic
-from openmdao.components.interp_util.interp_lagrange2 import InterpLagrange2
-from openmdao.components.interp_util.interp_lagrange3 import InterpLagrange3
+from openmdao.components.interp_util.interp_lagrange2 import InterpLagrange2, Interp3DLagrange2
+from openmdao.components.interp_util.interp_lagrange3 import InterpLagrange3, Interp3DLagrange3
 from openmdao.components.interp_util.interp_scipy import InterpScipy
-from openmdao.components.interp_util.interp_slinear import InterpLinear
-from openmdao.components.interp_util.interp_trilinear import InterpTrilinear
+from openmdao.components.interp_util.interp_slinear import InterpLinear, Interp3DSlinear
 
 from openmdao.components.interp_util.outofbounds_error import OutOfBoundsError
+from openmdao.utils.om_warnings import warn_deprecation
+
 
 INTERP_METHODS = {
     'slinear': InterpLinear,
@@ -23,16 +24,22 @@ INTERP_METHODS = {
     'lagrange3': InterpLagrange3,
     'cubic': InterpCubic,
     'akima': InterpAkima,
-    'akima1D': InterpAkima1D,
     'scipy_cubic': InterpScipy,
     'scipy_slinear': InterpScipy,
     'scipy_quintic': InterpScipy,
     'bsplines': InterpBSplines,
-    'trilinear': InterpTrilinear,
+    '3D-slinear': Interp3DSlinear,
+    '3D-lagrange2': Interp3DLagrange2,
+    '3D-lagrange3': Interp3DLagrange3,
+    '1D-akima': Interp1DAkima,
+    'trilinear': Interp3DSlinear,  # Deprecated
+    'akima1D': Interp1DAkima,  # Deprecated
 }
 
-TABLE_METHODS = ['slinear', 'lagrange2', 'lagrange3', 'cubic', 'akima', 'scipy_cubic',
-                 'scipy_slinear', 'scipy_quintic', 'trilinear', 'akima1D']
+TABLE_METHODS = ['slinear', 'lagrange2', 'lagrange3', 'cubic', 'akima',
+                 'scipy_cubic', 'scipy_slinear', 'scipy_quintic',
+                 'trilinear', 'akima1D',  # all Deprecated
+                 '3D-slinear', '1D-akima', '3D-lagrange2', '3D-lagrange3']
 SPLINE_METHODS = ['slinear', 'lagrange2', 'lagrange3', 'cubic', 'akima', 'bsplines',
                   'scipy_cubic', 'scipy_slinear', 'scipy_quintic']
 
@@ -127,6 +134,11 @@ class InterpND(object):
             all_m = ', '.join(['"' + m + '"' for m in INTERP_METHODS])
             raise ValueError('Interpolation method "%s" is not defined. Valid methods are '
                              '%s.' % (method, all_m))
+        elif method == 'akima1D':
+            warn_deprecation("The 'akima1D' method has been renamed to '1D-akima'.")
+        elif method == 'trilinear':
+            warn_deprecation("The 'trilinear' method has been renamed to '3D-slinear'.")
+
         self.extrapolate = extrapolate
 
         # The table points are always defined, by specifying either the points directly, or num_cp.
@@ -240,6 +252,9 @@ class InterpND(object):
             # Input is a list or tuple of separate points.
             x = np.atleast_2d(x)
 
+        # cache latest evaluation point for gradient method's use later
+        self._xi = x
+
         xnew = self._interpolate(x)
 
         if compute_derivative:
@@ -272,6 +287,9 @@ class InterpND(object):
         if len(values.shape) == 1:
             values = np.expand_dims(values, axis=0)
 
+        # cache latest evaluation point for gradient method's use later
+        self._xi = self.x_interp.copy()
+
         result = self._evaluate_spline(values)
         if result.shape[0] == 1:
             # Not vectorized, so drop the extra dimension.
@@ -301,9 +319,6 @@ class InterpND(object):
         ndarray
             Value of interpolant at all sample points.
         """
-        # cache latest evaluation point for gradient method's use later
-        self._xi = xi
-
         if not self.extrapolate:
             for i, p in enumerate(xi.T):
                 if np.isnan(p).any():
@@ -311,8 +326,7 @@ class InterpND(object):
                                            i, np.NaN, self.grid[i][0], self.grid[i][-1])
 
                 eps = 1e-14 * self.grid[i][-1]
-                if not np.logical_and(np.all(self.grid[i][0] <= p + eps),
-                                      np.all(p - eps <= self.grid[i][-1])):
+                if np.any(p < self.grid[i][0] - eps) or np.any(p > self.grid[i][-1] + eps):
                     p1 = np.where(self.grid[i][0] > p)[0]
                     p2 = np.where(p > self.grid[i][-1])[0]
                     # First violating entry is enough to direct the user.
@@ -337,7 +351,6 @@ class InterpND(object):
             result, derivs_x, derivs_val, derivs_grid = table.evaluate_vectorized(xi)
 
         else:
-            xi = np.atleast_2d(xi)
             n_nodes, nx = xi.shape
             result = np.empty((n_nodes, ), dtype=xi.dtype)
             derivs_x = np.empty((n_nodes, nx), dtype=xi.dtype)
@@ -345,7 +358,7 @@ class InterpND(object):
 
             # TODO: it might be possible to vectorize over n_nodes.
             for j in range(n_nodes):
-                val, d_x, d_values, d_grid = table.evaluate(xi[j, :])
+                val, d_x, d_values, d_grid = table.evaluate(xi[j, ...])
                 result[j] = val
                 derivs_x[j, :] = d_x.ravel()
                 if d_values is not None:
@@ -384,9 +397,6 @@ class InterpND(object):
         xi = self.x_interp
         self.values = values
 
-        # cache latest evaluation point for gradient method's use later
-        self._xi = xi.copy()
-
         table = self.table
         if table._vectorized:
 
@@ -472,7 +482,18 @@ class InterpND(object):
             # If inputs have changed since last computation, then re-interpolate.
             self.interpolate(xi)
 
-        return self._d_dx.reshape(np.asarray(xi).shape)
+        return self._gradient().reshape(np.asarray(xi).shape)
+
+    def _gradient(self):
+        """
+        Return the pre-computed gradients.
+
+        Returns
+        -------
+        ndarray
+            Vector of gradients of the interpolated values with respect to each value in xi.
+        """
+        return self._d_dx
 
     def training_gradients(self, pt):
         """
