@@ -3,7 +3,8 @@ import unittest
 import numpy as np
 
 import openmdao.api as om
-from openmdao.utils.assert_utils import assert_near_equal, assert_check_partials
+from openmdao.utils.assert_utils import assert_near_equal, assert_check_partials, assert_warning
+from openmdao.utils.om_warnings import OMDeprecationWarning
 
 
 class TestDemuxCompOptions(unittest.TestCase):
@@ -92,6 +93,19 @@ class TestDemuxComp1D(unittest.TestCase):
         assert_check_partials(cpd, atol=1.0E-8, rtol=1.0E-8)
 
 
+class TestDemuxComp(unittest.TestCase):
+
+    def test_demux_deprecation(self):
+
+        p = om.Problem()
+
+        msg = ("DemuxComp is being deprecated. This same functionality can be achieved "
+               "directly in the connect/promotes indices arg using om.slicer.")
+
+        with assert_warning(OMDeprecationWarning, msg):
+            p.model.add_subsystem(name='demux', subsys=om.DemuxComp(vec_size=4))
+
+
 class TestDemuxComp2D(unittest.TestCase):
 
     def setUp(self):
@@ -139,6 +153,7 @@ class TestDemuxComp2D(unittest.TestCase):
         cpd = self.p.check_partials(compact_print=False, method='cs', out_stream=None)
         assert_check_partials(cpd, atol=1.0E-8, rtol=1.0E-8)
 
+
 class TestDemuxComp3D(unittest.TestCase):
 
     def setUp(self):
@@ -240,9 +255,6 @@ class TestFeature(unittest.TestCase):
         """
         An example demonstrating a trivial use case of DemuxComp
         """
-        import numpy as np
-
-        import openmdao.api as om
         # The number of elements to be demuxed
         n = 3
 
@@ -258,9 +270,9 @@ class TestFeature(unittest.TestCase):
 
         p.model.add_subsystem(name='longitude_comp',
                               subsys=om.ExecComp('long = atan(y/x)',
-                                                 x={'value': np.ones(m), 'units': 'km'},
-                                                 y={'value': np.ones(m), 'units': 'km'},
-                                                 long={'value': np.ones(m), 'units': 'rad'}))
+                                                 x={'val': np.ones(m), 'units': 'km'},
+                                                 y={'val': np.ones(m), 'units': 'km'},
+                                                 long={'val': np.ones(m), 'units': 'rad'}))
 
         p.model.connect('demux.pos_ecef_0', 'longitude_comp.x')
         p.model.connect('demux.pos_ecef_1', 'longitude_comp.y')
