@@ -33,12 +33,12 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         prob.model.add_subsystem('mm', mm)
         prob.setup()
 
-        mm.options['train:x'] = [0.0, 0.4, 1.0]
-        mm.options['train:y'] = [3.02720998, 0.11477697, 15.82973195]
-        mm.options['train:x_fi2'] = [0.0, 0.4, 1.0]
-        mm.options['train:y_fi2'] = [3.02720998, 0.11477697, 15.82973195]
-        mm.options['train:x_fi3'] = [0.0, 0.4, 1.0]
-        mm.options['train:y_fi3'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x'] = [0.0, 0.4, 1.0]
+        mm.options['train_y'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x_fi2'] = [0.0, 0.4, 1.0]
+        mm.options['train_y_fi2'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x_fi3'] = [0.0, 0.4, 1.0]
+        mm.options['train_y_fi3'] = [3.02720998, 0.11477697, 15.82973195]
 
         with self.assertRaises(RuntimeError) as cm:
             prob.run_model()
@@ -58,15 +58,15 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         prob.model.add_subsystem('mm', mm)
         prob.setup()
 
-        mm.options['train:x'] = [0.0, 0.4, 1.0]
-        mm.options['train:x2'] = [0.0, 0.4, 1.0, 999.0]
-        mm.options['train:y'] = [3.02720998, 0.11477697, 15.82973195]
-        mm.options['train:x_fi2'] = [0.0, 0.4, 1.0]
-        mm.options['train:x2_fi2'] = [0.0, 0.4, 1.0]
-        mm.options['train:y_fi2'] = [3.02720998, 0.11477697, 15.82973195]
-        mm.options['train:x_fi3'] = [0.0, 0.4, 1.0]
-        mm.options['train:x2_fi3'] = [0.0, 0.4, 1.0]
-        mm.options['train:y_fi3'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x'] = [0.0, 0.4, 1.0]
+        mm.options['train_x2'] = [0.0, 0.4, 1.0, 999.0]
+        mm.options['train_y'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x_fi2'] = [0.0, 0.4, 1.0]
+        mm.options['train_x2_fi2'] = [0.0, 0.4, 1.0]
+        mm.options['train_y_fi2'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x_fi3'] = [0.0, 0.4, 1.0]
+        mm.options['train_x2_fi3'] = [0.0, 0.4, 1.0]
+        mm.options['train_y_fi3'] = [3.02720998, 0.11477697, 15.82973195]
 
         with self.assertRaises(RuntimeError) as cm:
             prob.run_model()
@@ -86,15 +86,15 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         prob.model.add_subsystem('mm', mm)
         prob.setup()
 
-        mm.options['train:x'] = [0.0, 0.4, 1.0]
-        mm.options['train:y'] = [3.02720998, 0.11477697, 15.82973195]
-        mm.options['train:y'] = [3.02720998, 0.11477697, 15.82973195, 3.14159]
-        mm.options['train:x_fi2'] = [0.0, 0.4, 1.0]
-        mm.options['train:y_fi2'] = [3.02720998, 0.11477697, 15.82973195]
-        mm.options['train:y_fi2'] = [3.02720998, 0.11477697, 15.82973195]
-        mm.options['train:x_fi3'] = [0.0, 0.4, 1.0]
-        mm.options['train:y_fi3'] = [3.02720998, 0.11477697, 15.82973195]
-        mm.options['train:y_fi3'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x'] = [0.0, 0.4, 1.0]
+        mm.options['train_y'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_y'] = [3.02720998, 0.11477697, 15.82973195, 3.14159]
+        mm.options['train_x_fi2'] = [0.0, 0.4, 1.0]
+        mm.options['train_y_fi2'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_y_fi2'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x_fi3'] = [0.0, 0.4, 1.0]
+        mm.options['train_y_fi3'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_y_fi3'] = [3.02720998, 0.11477697, 15.82973195]
 
         with self.assertRaises(RuntimeError) as cm:
             prob.run_model()
@@ -112,12 +112,12 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         prob.model.add_subsystem('mm', mm)
         prob.setup()
 
-        self.assertEqual(mm.options['train:x'], None)
-        self.assertEqual(mm.options['train:x_fi2'], None)
-        self.assertEqual(mm.options['train:x_fi3'], None)
-        self.assertEqual(mm.options['train:y'], None)
-        self.assertEqual(mm.options['train:y_fi2'], None)
-        self.assertEqual(mm.options['train:y_fi3'], None)
+        self.assertEqual(mm.options['train_x'], None)
+        self.assertEqual(mm.options['train_x_fi2'], None)
+        self.assertEqual(mm.options['train_x_fi3'], None)
+        self.assertEqual(mm.options['train_y'], None)
+        self.assertEqual(mm.options['train_y_fi2'], None)
+        self.assertEqual(mm.options['train_y_fi3'], None)
 
     def test_one_dim_one_fidelity_training(self):
         mm = om.MultiFiMetaModelUnStructuredComp()
@@ -130,8 +130,8 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         prob.model.add_subsystem('mm', mm)
         prob.setup()
 
-        mm.options['train:x'] = [0.0, 0.4, 1.0]
-        mm.options['train:y'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x'] = [0.0, 0.4, 1.0]
+        mm.options['train_y'] = [3.02720998, 0.11477697, 15.82973195]
 
         expected_xtrain=[np.array([[0.0], [0.4], [1.0]])]
         expected_ytrain=[np.array([[3.02720998], [0.11477697], [15.82973195]])]
@@ -157,8 +157,8 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         prob.model.add_subsystem('mm', mm)
         prob.setup()
 
-        mm.options['train:x'] = [0.0, 0.4, 1.0]
-        mm.options['train:y'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_x'] = [0.0, 0.4, 1.0]
+        mm.options['train_y'] = [3.02720998, 0.11477697, 15.82973195]
 
         expected_xtrain=[np.array([[0.0], [0.4], [1.0]])]
         expected_ytrain=[np.array([[3.02720998], [0.11477697], [15.82973195]])]
@@ -191,11 +191,11 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         prob.model.add_subsystem('mm', mm)
         prob.setup()
 
-        mm.options['train:x']= [0.0, 0.4, 1.0]
-        mm.options['train:x_fi2'] = [0.1, 0.2, 0.3, 0.5, 0.6,
+        mm.options['train_x']= [0.0, 0.4, 1.0]
+        mm.options['train_x_fi2'] = [0.1, 0.2, 0.3, 0.5, 0.6,
                                   0.7, 0.8, 0.9, 0.0, 0.4, 1.0]
-        mm.options['train:y'] = [3.02720998, 0.11477697, 15.82973195]
-        mm.options['train:y_fi2'] = [-9.32828839, -8.31986355, -7.00778837,
+        mm.options['train_y'] = [3.02720998, 0.11477697, 15.82973195]
+        mm.options['train_y_fi2'] = [-9.32828839, -8.31986355, -7.00778837,
                                   -4.54535129, -4.0747189 , -5.30287702,
                                   -4.47456522, 1.85597517, -8.48639501,
                                   -5.94261151, 7.91486597]
@@ -226,14 +226,14 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         prob.model.add_subsystem('mm', mm)
         prob.setup()
 
-        mm.options['train:x1']     = [1.0, 2.0, 3.0]
-        mm.options['train:x1_fi2'] = [1.1, 2.1, 3.1, 1.0, 2.0, 3.0]
-        mm.options['train:x2']     = [1.0, 2.0, 3.0]
-        mm.options['train:x2_fi2'] = [2.1, 2.2, 2.3, 1.0, 2.0, 3.0]
-        mm.options['train:y1']     = [0.0, 0.1, 0.2]
-        mm.options['train:y1_fi2'] = [3.0, 3.1, 3.3, 3.4, 3.5 ,3.6]
-        mm.options['train:y2']     = [4.0, 4.0, 4.0]
-        mm.options['train:y2_fi2'] = [4.0, 4.1, 4.3, 4.4, 4.5 ,4.6]
+        mm.options['train_x1']     = [1.0, 2.0, 3.0]
+        mm.options['train_x1_fi2'] = [1.1, 2.1, 3.1, 1.0, 2.0, 3.0]
+        mm.options['train_x2']     = [1.0, 2.0, 3.0]
+        mm.options['train_x2_fi2'] = [2.1, 2.2, 2.3, 1.0, 2.0, 3.0]
+        mm.options['train_y1']     = [0.0, 0.1, 0.2]
+        mm.options['train_y1_fi2'] = [3.0, 3.1, 3.3, 3.4, 3.5 ,3.6]
+        mm.options['train_y2']     = [4.0, 4.0, 4.0]
+        mm.options['train_y2_fi2'] = [4.0, 4.1, 4.3, 4.4, 4.5 ,4.6]
 
         prob.run_model()
         expected_xtrain=[np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0]]),
@@ -307,10 +307,10 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         y = np.array([[branin(case) for case in x[0]],
                       [branin_low_fidelity(case) for case in x[1]]])
 
-        mm.options['train:x'] = x[0]
-        mm.options['train:y'] = y[0]
-        mm.options['train:x_fi2'] = x[1]
-        mm.options['train:y_fi2'] = y[1]
+        mm.options['train_x'] = x[0]
+        mm.options['train_y'] = y[0]
+        mm.options['train_x_fi2'] = x[1]
+        mm.options['train_y_fi2'] = y[1]
 
         prob['mm.x'] = np.array([[2./3., 1./3.]])
         prob.run_model()
@@ -334,10 +334,10 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
         prob.model.add_subsystem('mm', mm)
         prob.setup()
 
-        mm.options['train:x'] = x[0]
-        mm.options['train:y'] = y[0]
-        mm.options['train:x_fi2'] = x[1]
-        mm.options['train:y_fi2'] = y[1]
+        mm.options['train_x'] = x[0]
+        mm.options['train_y'] = y[0]
+        mm.options['train_x_fi2'] = x[1]
+        mm.options['train_y_fi2'] = y[1]
 
         prob['mm.x'] = np.array([[[2./3., 1./3.]], [[1./3., 2./3.]]])
         prob.run_model()
@@ -362,10 +362,10 @@ class MultiFiMetaModelTestCase(unittest.TestCase):
              [[ 0.91430235,  0.17029894],  # cheap (lowfi) doe
               [ 0.40806563,  0.91465314]]]
 
-        mm.options['train:x'] = x[0]
-        mm.options['train:y'] = np.array([1, 2, 3])
-        mm.options['train:x_fi2'] = x[1]
-        mm.options['train:y_fi2'] = np.array([1, 2])
+        mm.options['train_x'] = x[0]
+        mm.options['train_y'] = np.array([1, 2, 3])
+        mm.options['train_x_fi2'] = x[1]
+        mm.options['train_y_fi2'] = np.array([1, 2])
 
         prob['mm.x'] = np.array([[2./3., 1./3.]])
 
@@ -473,10 +473,10 @@ class MultiFiMetaModelFeatureTestCase(unittest.TestCase):
                        171.46115394210995,
                        138.87939632355875])
 
-        mm.options['train:x'] = x_hifi
-        mm.options['train:y'] = y_hifi
-        mm.options['train:x_fi2'] = x_lofi
-        mm.options['train:y_fi2'] = y_lofi
+        mm.options['train_x'] = x_hifi
+        mm.options['train_y'] = y_hifi
+        mm.options['train_x_fi2'] = x_lofi
+        mm.options['train_y_fi2'] = y_lofi
 
         prob.set_val('mm.x', np.array([[2./3., 1./3.]]))
         prob.run_model()
