@@ -22,8 +22,6 @@ class DistributedAdder(ExplicitComponent):
     """
 
     def initialize(self):
-        self.options['distributed'] = True
-
         self.options.declare('size', types=int, default=1,
                              desc="Size of input and output vectors.")
 
@@ -44,9 +42,9 @@ class DistributedAdder(ExplicitComponent):
         start = local_offset
         end = local_offset + local_size
 
-        self.add_input('x', val=np.zeros(local_size, float),
+        self.add_input('x', val=np.zeros(local_size, float), distributed=True,
                        src_indices=np.arange(start, end, dtype=int))
-        self.add_output('y', val=np.zeros(local_size, float))
+        self.add_output('y', val=np.zeros(local_size, float), distributed=True)
 
     def compute(self, inputs, outputs):
 
