@@ -285,15 +285,15 @@ class TestGetSetVariables(unittest.TestCase):
         p = Problem()
         p.model.add_subsystem('indep', IndepVarComp('x', val=np.ones(10)), promotes=['x'])
         p.model.add_subsystem('C1', ExecComp('y=x*2.',
-                                             x={'value': np.zeros(7),
-                                                'src_indices': list(range(7))},
-                                             y={'value': np.zeros(7)}),
-                              promotes=['x'])
+                                             x={'val': np.zeros(7)},
+                                             y={'val': np.zeros(7)}))
         p.model.add_subsystem('C2', ExecComp('y=x*3.',
-                                             x={'value': np.zeros(3),
-                                                'src_indices': list(range(7,10))},
-                                             y={'value': np.zeros(3)}),
-                              promotes=['x'])
+                                             x={'val': np.zeros(3)},
+                                             y={'val': np.zeros(3)}))
+
+        p.model.promotes('C1', inputs=['x'], src_indices=list(range(7)))
+        p.model.promotes('C2', inputs=['x'], src_indices=list(range(7, 10)))
+
         p.setup()
 
         p['C1.x'] = (np.arange(7) + 1.) * 2.
@@ -313,17 +313,17 @@ class TestGetSetVariables(unittest.TestCase):
         indep = p.model.add_subsystem('indep', IndepVarComp(), promotes=['x'])
         indep.add_output('x', units='inch', val=np.ones(10))
         p.model.add_subsystem('C1', ExecComp('y=x*2.',
-                                             x={'value': np.zeros(7),
-                                                'units': 'ft',
-                                                'src_indices': list(range(7))},
-                                             y={'value': np.zeros(7), 'units': 'ft'}),
-                              promotes=['x'])
+                                             x={'val': np.zeros(7),
+                                                'units': 'ft'},
+                                             y={'val': np.zeros(7), 'units': 'ft'}))
         p.model.add_subsystem('C2', ExecComp('y=x*3.',
-                                             x={'value': np.zeros(3),
-                                                'units': 'inch',
-                                                'src_indices': list(range(7,10))},
-                                             y={'value': np.zeros(3), 'units': 'inch'}),
-                              promotes=['x'])
+                                             x={'val': np.zeros(3),
+                                                'units': 'inch'},
+                                             y={'val': np.zeros(3), 'units': 'inch'}))
+
+        p.model.promotes('C1', inputs=['x'], src_indices=list(range(7)))
+        p.model.promotes('C2', inputs=['x'], src_indices=list(range(7, 10)))
+
         p.setup()
 
         p['C1.x'] = np.ones(7) * 2.
@@ -341,22 +341,21 @@ class TestGetSetVariables(unittest.TestCase):
     def test_serial_multi_src_inds_units_promoted_no_src(self):
         p = Problem()
         p.model.add_subsystem('C1', ExecComp('y=x*2.',
-                                             x={'value': np.zeros(7),
-                                                'units': 'ft',
-                                                'src_indices': list(range(7))},
-                                             y={'value': np.zeros(7), 'units': 'ft'}),
-                              promotes=['x'])
+                                             x={'val': np.zeros(7),
+                                                'units': 'ft'},
+                                             y={'val': np.zeros(7), 'units': 'ft'}))
         p.model.add_subsystem('C2', ExecComp('y=x*3.',
-                                             x={'value': np.zeros(3),
-                                                'units': 'inch',
-                                                'src_indices': list(range(7, 10))},
-                                             y={'value': np.zeros(3), 'units': 'inch'}),
-                              promotes=['x'])
+                                             x={'val': np.zeros(3),
+                                                'units': 'inch'},
+                                             y={'val': np.zeros(3), 'units': 'inch'}))
         p.model.add_subsystem('C3', ExecComp('y=x*4.',
-                                             x={'value': np.zeros(10), 'units': 'mm'},
-                                             y={'value': np.zeros(10), 'units': 'mm'}),
+                                             x={'val': np.zeros(10), 'units': 'mm'},
+                                             y={'val': np.zeros(10), 'units': 'mm'}),
                          promotes=['x'])
 
+        p.model.promotes('C1', inputs=['x'], src_indices=list(range(7)))
+        p.model.promotes('C2', inputs=['x'], src_indices=list(range(7, 10)))
+
         with self.assertRaises(RuntimeError) as cm:
             p.setup()
 
@@ -367,17 +366,17 @@ class TestGetSetVariables(unittest.TestCase):
         indep = p.model.add_subsystem('indep', IndepVarComp(), promotes=['x'])
         indep.add_output('x', units='inch', val=np.ones(10))
         p.model.add_subsystem('C1', ExecComp('y=x*2.',
-                                             x={'value': np.zeros(7),
-                                                'units': 'ft',
-                                                'src_indices': list(range(7))},
-                                             y={'value': np.zeros(7), 'units': 'ft'}),
-                              promotes=['x'])
+                                             x={'val': np.zeros(7),
+                                                'units': 'ft'},
+                                             y={'val': np.zeros(7), 'units': 'ft'}))
         p.model.add_subsystem('C2', ExecComp('y=x*3.',
-                                             x={'value': np.zeros(3),
-                                                'units': 'inch',
-                                                'src_indices': list(range(7,10))},
-                                             y={'value': np.zeros(3), 'units': 'inch'}),
-                              promotes=['x'])
+                                             x={'val': np.zeros(3),
+                                                'units': 'inch'},
+                                             y={'val': np.zeros(3), 'units': 'inch'}))
+
+        p.model.promotes('C1', inputs=['x'], src_indices=list(range(7)))
+        p.model.promotes('C2', inputs=['x'], src_indices=list(range(7, 10)))
+
         p.setup()
 
         p.set_val('C1.x', np.ones(7) * 24., units='inch')
