@@ -6,6 +6,7 @@ formulating and solving nonlinear constrained optimization problems, with
 additional MPI capability.
 """
 
+import sys
 from collections import OrderedDict
 import json
 import signal
@@ -137,8 +138,9 @@ class pyOptSparseDriver(Driver):
         Pyopt_sparse solution object.
     _check_jac : bool
         Used internally to control when to perform singular checks on computed total derivs.
-    _exc_info : None or <Exception>
-        Cached exception that was raised in the _objfunc or _gradfunc callbacks.
+    _exc_info : 3 item tuple
+        Storage for exception and traceback information for exception that was raised in the
+        _objfunc or _gradfunc callbacks.
     _in_user_function :bool
         This is set to True at the start of a pyoptsparse callback to _objfunc and _gradfunc, and
         restored to False at the finish of each callback.
@@ -212,6 +214,12 @@ class pyOptSparseDriver(Driver):
         self.options.declare('print_results', types=bool, default=True,
                              desc='Print pyOpt results if True')
         self.options.declare('gradient method', default='openmdao',
+                             values={'openmdao', 'pyopt_fd', 'snopt_fd'},
+                             desc='Finite difference implementation to use',
+                             deprecation=(f"'gradient method' is not a valid python name and will "
+                                          "raise an exception in a future release.  Use "
+                                          "'gradient_method' instead.", 'gradient_method'))
+        self.options.declare('gradient_method', default='openmdao',
                              values={'openmdao', 'pyopt_fd', 'snopt_fd'},
                              desc='Finite difference implementation to use')
         self.options.declare('user_terminate_signal', default=DEFAULT_SIGNAL, allow_none=True,
@@ -231,8 +239,9 @@ class pyOptSparseDriver(Driver):
         self.options.declare('user_teriminate_signal', default=None, allow_none=True,
                              desc='OS signal that triggers a clean user-termination. Only SNOPT'
                              'supports this option.',
-                             deprecation="The option 'user_teriminate_signal' was misspelled and "
-                             "will be deprecated. Please use 'user_terminate_signal' instead.")
+                             deprecation=("The option 'user_teriminate_signal' was misspelled and "
+                                          "will be deprecated. Please use 'user_terminate_signal' "
+                                          "instead.", 'user_terminate_signal'))
 
     def _setup_driver(self, problem):
         """
@@ -444,7 +453,7 @@ class pyOptSparseDriver(Driver):
         try:
 
             # Execute the optimization problem
-            if self.options['gradient method'] == 'pyopt_fd':
+            if self.options['gradient_method'] == 'pyopt_fd':
 
                 # Use pyOpt's internal finite difference
                 # TODO: Need to get this from OpenMDAO
@@ -453,7 +462,7 @@ class pyOptSparseDriver(Driver):
                 sol = opt(opt_prob, sens='FD', sensStep=fd_step, storeHistory=self.hist_file,
                           hotStart=self.hotstart_file)
 
-            elif self.options['gradient method'] == 'snopt_fd':
+            elif self.options['gradient_method'] == 'snopt_fd':
                 if self.options['optimizer'] == 'SNOPT':
 
                     # Use SNOPT's internal finite difference
@@ -465,7 +474,7 @@ class pyOptSparseDriver(Driver):
 
                 else:
                     msg = "SNOPT's internal finite difference can only be used with SNOPT"
-                    self._exc_info = Exception(msg)
+                    self._exc_info = (Exception, Exception(msg), None)
             else:
 
                 # Use OpenMDAO's differentiator for the gradient
@@ -474,10 +483,12 @@ class pyOptSparseDriver(Driver):
 
         except Exception as _:
             if not self._exc_info:
-                raise()
+                raise
 
         if self._exc_info:
-            raise self._exc_info
+            if self._exc_info[2] is None:
+                raise self._exc_info[1]
+            raise self._exc_info[1].with_traceback(self._exc_info[2])
 
         # Print results
         if self.options['print_results']:
@@ -594,8 +605,8 @@ class pyOptSparseDriver(Driver):
                 rec.abs = 0.0
                 rec.rel = 0.0
 
-        except Exception as raised:
-            self._exc_info = raised
+        except Exception:
+            self._exc_info = sys.exc_info()
             fail = 1
             func_dict = {}
 
@@ -694,8 +705,8 @@ class pyOptSparseDriver(Driver):
                         isize = len(ival)
                         sens_dict[okey][ikey] = np.zeros((osize, isize))
 
-        except Exception as raised:
-            self._exc_info = raised
+        except Exception:
+            self._exc_info = sys.exc_info()
             fail = 1
             sens_dict = {}
 
