@@ -4,6 +4,7 @@ from collections import defaultdict
 from distutils.version import LooseVersion
 
 import numpy as np
+import pickle
 
 from openmdao.core.group import Group
 from openmdao.core.component import Component
@@ -506,6 +507,66 @@ def _check_missing_recorders(problem, logger):
     logger.warning(msg)
 
 
+def _check_unserializable_options(problem, logger, check_recordable=True):
+    """
+    Check if there are any options that are not serializable, and therefore won't be recorded.
+
+    Parameters
+    ----------
+    problem : <Problem>
+        The problem being checked.
+    logger : object
+        The object that manages logging output.
+    check_recordable : bool
+        If False, warn about all unserializable options.
+        If True, warn only about unserializable options that do not have 'recordable' set to False.
+    """
+    from openmdao.recorders.case_recorder import PICKLE_VER
+
+    def _check_opts(obj, name=None):
+        if obj:
+            for key, val in obj.options.items():
+                try:
+                    pickle.dumps(val, PICKLE_VER)
+                except Exception:
+                    name_str = name + " " if name else ""
+                    if obj.options._dict[key]['recordable']:
+                        msg = f"{obj.msginfo}: {name_str}option '{key}' is not serializable " \
+                              "(cannot be pickled) but 'recordable=False' has not been set. " \
+                              f"No options will be recorded for this {obj.__class__.__name__} " \
+                              "unless 'recordable' is set to False for this option."
+                        logger.warning(msg)
+                    elif not check_recordable:
+                        msg = f"{obj.msginfo}: {name_str}option '{key}' is not serializable " \
+                              "(cannot be pickled) and will not be recorded."
+                        logger.warning(msg)
+
+    # check options for all for Systems and Solvers
+    for system in problem.model.system_iter(include_self=True, recurse=True):
+        _check_opts(system)
+        _check_opts(system.linear_solver, 'linear_solver')
+
+        nl = system.nonlinear_solver
+        if nl:
+            _check_opts(nl, 'nonlinear_solver')
+            for name in ('linear_solver', 'linesearch'):
+                _check_opts(getattr(nl, name, None), name)
+
+
+def _check_all_unserializable_options(problem, logger):
+    """
+    Check if there are any options that are not serializable, and therefore won't be recorded.
+
+    Parameters
+    ----------
+    problem : <Problem>
+        The problem being checked.
+    logger : object
+        The object that manages logging output.
+    """
+    _check_unserializable_options(problem, logger, False)
+
+
 def _get_promoted_connected_ins(g):
     """
     Find all inputs that are promoted above the level where they are explicitly connected.
@@ -580,6 +641,7 @@ _default_checks = {
     'solvers': _check_solvers,
     'dup_inputs': _check_dup_comp_inputs,
     'missing_recorders': _check_missing_recorders,
+    'unserializable_options': _check_unserializable_options,
     'comp_has_no_outputs': _check_comp_has_no_outputs,
     'auto_ivc_warnings': _check_auto_ivc_warnings
 }
@@ -589,8 +651,12 @@ _all_checks.update({
     'cycles': _check_cycles_prob,
     'unconnected_inputs': _check_hanging_inputs,
     'promotions': _check_explicitly_connected_promoted_inputs,
+    'all_unserializable_options': _check_all_unserializable_options,
 })
 
+_all_non_redundant_checks = _all_checks.copy()
+del _all_non_redundant_checks['unserializable_options']
+
 
 #
 # Command line interface functions
@@ -641,7 +707,7 @@ def _check_config_cmd(options, user_args):
             if not options.checks:
                 options.checks = sorted(_default_checks)
             elif 'all' in options.checks:
-                options.checks = sorted(_all_checks)
+                options.checks = sorted(_all_non_redundant_checks)
 
             prob.check_config(logger, options.checks)
 
