@@ -7,6 +7,13 @@ from openmdao.matrices.coo_matrix import COOMatrix
 class CSRMatrix(COOMatrix):
     """
     Sparse matrix in Compressed Row Storage format.
+
+    Parameters
+    ----------
+    comm : MPI.Comm or <FakeComm>
+        Communicator of the top-level system that owns the <Jacobian>.
+    is_internal : bool
+        If True, this is the int_mtx of an AssembledJacobian.
     """
 
     def _build(self, num_rows, num_cols, in_ranges, out_ranges):
