@@ -9,6 +9,14 @@ class LinearUserDefined(LinearSolver):
 
     This is a solver that wraps a user-written linear solve function.
 
+    Parameters
+    ----------
+    solve_function : function
+        Custom function containing the solve_linear function. The default is None, which means
+        the name defaults to "solve_linear".
+    **kwargs : dict
+        Options dictionary.
+
     Attributes
     ----------
     solve_function : function
@@ -21,14 +29,6 @@ class LinearUserDefined(LinearSolver):
     def __init__(self, solve_function=None, **kwargs):
         """
         Initialize all attributes.
-
-        Parameters
-        ----------
-        solve_function : function
-            Custom function containing the solve_linear function. The default is None, which means
-            the name defaults to "solve_linear".
-        **kwargs : dict
-            Options dictionary.
         """
         super().__init__(**kwargs)
 
@@ -42,7 +42,7 @@ class LinearUserDefined(LinearSolver):
 
         Parameters
         ----------
-        mode : string
+        mode : str
             Derivative mode, can be 'fwd' or 'rev'.
         rel_systems : set of str
             Set of names of relevant systems based on the current linear solve.
