@@ -14,8 +14,6 @@ class DistribComp(om.ExplicitComponent):
     """Simple Distributed Component."""
 
     def initialize(self):
-        self.options['distributed'] = True
-
         self.options.declare('size', types=int, default=1,
                              desc="Size of input and output vectors.")
 
@@ -27,15 +25,11 @@ class DistribComp(om.ExplicitComponent):
 
         # if comm.size is 2 and size is 15, this results in
         # 8 entries for proc 0 and 7 entries for proc 1
-        sizes, offsets = evenly_distrib_idxs(comm.size, size)
+        sizes, _ = evenly_distrib_idxs(comm.size, size)
         mysize = sizes[rank]
-        start = offsets[rank]
-        end = start + mysize
 
-        self.add_input('invec', np.ones(mysize, float),
-                       src_indices=np.arange(start, end, dtype=int))
-
-        self.add_output('outvec', np.ones(mysize, float))
+        self.add_input('invec', np.ones(mysize, float), distributed=True)
+        self.add_output('outvec', np.ones(mysize, float), distributed=True,)
 
     def compute(self, inputs, outputs):
         if self.comm.rank == 0:
@@ -64,8 +58,6 @@ class DistribCompDerivs(om.ExplicitComponent):
     """Simple Distributed Component with Derivatives."""
 
     def initialize(self):
-        self.options['distributed'] = True
-
         self.options.declare('size', types=int, default=1,
                              desc="Size of input and output vectors.")
 
@@ -81,8 +73,8 @@ class DistribCompDerivs(om.ExplicitComponent):
         self.mysize = mysize = sizes[rank]
 
         # don't set src_indices on the input, just use default behavior
-        self.add_input('invec', np.ones(mysize, float))
-        self.add_output('outvec', np.ones(mysize, float))
+        self.add_input('invec', np.ones(mysize, float), distributed=True)
+        self.add_output('outvec', np.ones(mysize, float), distributed=True)
 
     def setup_partials(self):
         # declare partial derivatives (diagonal of mysize)
