@@ -9,7 +9,7 @@ from openmdao.test_suite.components.sellar import SellarImplicitDis1
 class SubSellar(om.Group):
 
     def __init__(self, units=None, scaling=None, **kwargs):
-        super(SubSellar, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.add_subsystem('d1', SellarDis1withDerivatives(units=units, scaling=scaling),
                            promotes=['x', 'z', 'y1', 'y2'])
@@ -23,7 +23,7 @@ class SubSellar(om.Group):
 class DoubleSellar(om.Group):
 
     def __init__(self, units=None, scaling=None, **kwargs):
-        super(DoubleSellar, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.add_subsystem('g1', SubSellar(units=units, scaling=scaling))
         self.add_subsystem('g2', SubSellar(units=units, scaling=scaling))
@@ -39,7 +39,7 @@ class DoubleSellar(om.Group):
 class SubSellarImplicit(om.Group):
 
     def __init__(self, units=None, scaling=None, **kwargs):
-        super(SubSellarImplicit, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.add_subsystem('d1', SellarImplicitDis1(units=units, scaling=scaling),
                            promotes=['x', 'z', 'y1', 'y2'])
@@ -50,7 +50,7 @@ class SubSellarImplicit(om.Group):
 class DoubleSellarImplicit(om.Group):
 
     def __init__(self, units=None, scaling=None, **kwargs):
-        super(DoubleSellarImplicit, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.add_subsystem('g1', SubSellar(units=units, scaling=scaling))
         self.add_subsystem('g2', SubSellar(units=units, scaling=scaling))
