@@ -5,9 +5,9 @@ Classes that handle array indexing.
 import sys
 import numpy as np
 from numbers import Integral
+from itertools import zip_longest
 
 from openmdao.utils.general_utils import shape2tuple
-from openmdao.utils.om_warnings import warn_deprecation
 from openmdao.utils.om_warnings import issue_warning, OMDeprecationWarning
 
 
@@ -59,8 +59,8 @@ class Indexer(object):
 
     Parameters
     ----------
-    flat_src : bool or None
-        If True, treat source as flat.
+    flat_src : bool
+        True if we're treating the source as flat.
 
     Attributes
     ----------
@@ -71,33 +71,18 @@ class Indexer(object):
         Cached shaped_instance if we've computed it before.
     _flat_src : bool
         If True, index is into a flat source array.
-    _dist_shape : tuple or None
-        Distributed shape.
-    _orig_src_shape : tuple or None
-        Original shape of the source, before possible flattening based on _flat_src flag.
+    _dist_shape : tuple
+        Distributed shape of the source.
     """
 
-    def __init__(self, flat_src):
+    def __init__(self, flat_src=None):
         """
         Initialize attributes.
         """
         self._src_shape = None
+        self._dist_shape = None
         self._shaped_inst = None
         self._flat_src = flat_src
-        self._dist_shape = None
-        # TODO: remove this after flat src deprecation branch
-        self._orig_src_shape = None
-
-    def __len__(self):
-        """
-        Return the length of the flattened indices.
-
-        Returns
-        -------
-        int
-            Length of flattened indices.
-        """
-        return self.size
 
     def __call__(self):
         """
@@ -121,22 +106,6 @@ class Indexer(object):
         """
         return f"{self.__class__.__name__}: {str(self)}"
 
-    def __eq__(self, other):
-        """
-        Return True if this indexer is equivalent to other.
-
-        Parameters
-        ----------
-        other : Indexer
-            The other Indexer.
-
-        Returns
-        -------
-        bool
-            True if Indexers are equivalent.
-        """
-        return np.all(self.as_array() == other.as_array())
-
     def copy(self, *args):
         """
         Copy this Indexer.
@@ -172,32 +141,38 @@ class Indexer(object):
         self._src_shape = parent._src_shape
         self._flat_src = parent._flat_src
         self._dist_shape = parent._dist_shape
-        self._orig_src_shape = parent._orig_src_shape
         return self
 
     @property
-    def size(self):
+    def indexed_src_shape(self):
         """
-        Return the size of the flattened indices.
+        Return the shape of the result if the indices were applied to a source array.
+
+        Returns
+        -------
+        tuple
+            The shape of the result.
+        """
+        s = self.shaped_instance()
+        if s is None:
+            raise RuntimeError(f"Can't get indexed_src_shape of {self} because source shape "
+                               "is unknown.")
+        if self._flat_src:
+            return resolve_shape(np.product(self._src_shape))[self.flat()]
+        else:
+            return resolve_shape(self._src_shape)[self()]
+
+    @property
+    def indexed_src_size(self):
+        """
+        Return the size of the result if the index were applied to the source.
 
         Returns
         -------
         int
             Size of flattened indices.
         """
-        return np.product(self.shape, dtype=int)
-
-    @property
-    def src_ndim(self):
-        """
-        Return the number of source dimensions.
-
-        Returns
-        -------
-        int
-            The number of dimensions expected in the source array.
-        """
-        return 1
+        return np.product(self.indexed_src_shape, dtype=int)
 
     def _check_ind_type(self, ind, types):
         if not isinstance(ind, types):
@@ -215,22 +190,6 @@ class Indexer(object):
         """
         raise NotImplementedError("No implementation of 'flat' found.")
 
-    @property
-    def shape(self):
-        """
-        Return the shape of the result if the indices were applied to a source array.
-
-        Returns
-        -------
-        tuple
-            The shape of the indices.
-        """
-        s = self.shaped_instance()
-        if s is None:
-            raise RuntimeError(f"Can't get shape of {self} because source shape "
-                               "is unknown.")
-        return s.shape
-
     def shaped_instance(self):
         """
         Return a 'shaped' version of this Indexer type.
@@ -301,8 +260,11 @@ class Indexer(object):
         Indexer
             Self is returned to allow chaining.
         """
-        self._orig_src_shape = shape
-        self._src_shape, self._dist_shape = self._get_shapes(shape, dist_shape)
+        if self._flat_src is None and shape is not None:
+            self._flat_src = len(shape2tuple(shape)) <= 1
+
+        self._src_shape, self._dist_shape, = self._get_shapes(shape, dist_shape)
+
         if shape is not None:
             self._check_bounds()
 
@@ -321,7 +283,7 @@ class Indexer(object):
             return None, None
 
         shape = shape2tuple(shape)
-        if self._flat_src or self._appears_flat():
+        if self._flat_src:
             shape = (np.product(shape),)
 
         if dist_shape is None:
@@ -333,52 +295,6 @@ class Indexer(object):
 
         return shape, dist_shape
 
-    def _appears_flat(self):
-        return True
-
-    def _check_flat_indices_warning(self, flat, src_shape, vname, prefix=''):
-        if src_shape is None or flat or not self._appears_flat():
-            return
-        src_shape = shape2tuple(src_shape)
-        if len(src_shape) > 1:
-            if flat is None:
-                issue_warning(f"Indexing into source variable '{vname}' of dimension "
-                              f"{len(src_shape)} using indices of dimension "
-                              f"{len(shape2tuple(self.shape))} without setting `flat_indices=True`."
-                              " The source is currently treated as flat, but this automatic "
-                              f"flattening is deprecated and will be removed in a future release. "
-                              "To keep the old behavior, set `flat_indices=True` when you set "
-                              "`indices`.", category=OMDeprecationWarning, prefix=prefix)
-            else:  # flat is False
-                raise IndexError(f"Indexing into source variable '{vname}' of dimension "
-                                 f"{len(src_shape)} using indices of dimension "
-                                 f"{len(shape2tuple(self.shape))} and setting "
-                                 "`flat_indices=False`. The current version of OpenMDAO assumes "
-                                 "a flat source if the indices appear flat, so `flat_indices=False`"
-                                 " is not a valid option. This behavior is "
-                                 "deprecated and will be removed in a later version.")
-
-    def _check_flat_src_indices_warning(self, flat, src_shape, tgt, prefix=''):
-        if src_shape is None or self._flat_src or flat or not self._appears_flat():
-            return
-        src_shape = shape2tuple(src_shape)
-        if len(src_shape) > 1:
-            if flat is None:
-                issue_warning(f"Indexing into a source array of dimension {len(src_shape)} "
-                              f"using indices of dimension {len(shape2tuple(self.shape))} without "
-                              f"setting `flat_src_indices=True` when connecting to input '{tgt}'. "
-                              "The source array is currently treated as flat, but this automatic "
-                              "flattening is deprecated and will be removed in a future release. "
-                              "To keep the old behavior, set `flat_src_indices=True` when you set "
-                              "`src_indices`.", category=OMDeprecationWarning, prefix=prefix)
-            else:  # flat is False
-                raise IndexError(f"Indexing into a source array of dimension {len(src_shape)} using"
-                                 f" indices of dimension {len(shape2tuple(self.shape))} and setting"
-                                 f" `flat_indices=False` when connecting to input '{tgt}'. The "
-                                 "current version of OpenMDAO assumes a flat source if the indices "
-                                 "appear flat, so `flat_indices=False` is not a valid option. This "
-                                 "behavior is deprecated and will be removed in a later version.")
-
 
 class ShapedIntIndexer(Indexer):
     """
@@ -439,19 +355,19 @@ class ShapedIntIndexer(Indexer):
         return super().copy(self._idx)
 
     @property
-    def size(self):
+    def min_src_dim(self):
         """
-        Return the size of the flattened indices.
+        Return the number of source dimensions.
 
         Returns
         -------
         int
-            Size of flattened indices.
+            The number of dimensions expected in the source array.
         """
         return 1
 
     @property
-    def shape(self):
+    def indexed_src_shape(self):
         """
         Return the shape of the index ().
 
@@ -460,7 +376,9 @@ class ShapedIntIndexer(Indexer):
         tuple
             The shape of the index.
         """
-        return 1
+        if self._flat_src:
+            return (1,)
+        return super().indexed_src_shape
 
     def as_array(self, copy=False, flat=True):
         """
@@ -541,14 +459,15 @@ class IntIndexer(ShapedIntIndexer):
         if self._shaped_inst is not None:
             return self._shaped_inst
 
-        if self._idx < 0:
-            if self._src_shape is None:
-                return None
-            else:
-                self._shaped_inst = ShapedIntIndexer(self._idx + self._src_shape[0])
-            return self._shaped_inst
+        if self._src_shape is None:
+            return None
 
-        return ShapedIntIndexer(self._idx)._set_attrs(self)
+        if self._idx < 0:
+            self._shaped_inst = ShapedIntIndexer(self._idx + self._src_shape[0])
+        else:
+            self._shaped_inst = ShapedIntIndexer(self._idx)
+
+        return self._shaped_inst._set_attrs(self)
 
 
 class ShapedSliceIndexer(Indexer):
@@ -652,17 +571,16 @@ class ShapedSliceIndexer(Indexer):
         return self._slice
 
     @property
-    def shape(self):
+    def min_src_dim(self):
         """
-        Return the shape of the indices.
+        Return the number of source dimensions.
 
         Returns
         -------
         int
-            The shape of the indices.
+            The number of dimensions expected in the source array.
         """
-        # use maxsize here since shaped slice always has positive int start and stop
-        return (len(range(*self._slice.indices(sys.maxsize))),)
+        return 1
 
     def _check_bounds(self):
         """
@@ -716,37 +634,17 @@ class SliceIndexer(ShapedSliceIndexer):
         if self._shaped_inst is not None:
             return self._shaped_inst
 
+        if self._src_shape is None:
+            return None
+
         slc = self._slice
         if (slc.start is not None and slc.start < 0) or slc.stop is None or slc.stop < 0:
-            if self._src_shape is None:
-                return None
-            else:
-                self._shaped_inst = ShapedSliceIndexer(
-                    slice(*self._slice.indices(self._src_shape[0])))._set_attrs(self)
-                return self._shaped_inst
+            self._shaped_inst = \
+                ShapedSliceIndexer(slice(*self._slice.indices(self._src_shape[0])))
+        else:
+            self._shaped_inst = ShapedSliceIndexer(slc)
 
-        return ShapedSliceIndexer(slc)._set_attrs(self)
-
-    @property
-    def shape(self):
-        """
-        Return the shape of the indices.
-
-        Returns
-        -------
-        int
-            The shape of the indices.
-        """
-        s = self.shaped_instance()
-        if s is None:
-            slc = self._slice
-            # if both start and stop are negative we can figure out the shape
-            if slc.start is not None and slc.start < 0 and slc.stop is not None and slc.stop < 0:
-                step = 1 if slc.step is None else slc.step
-                return (len(range(slc.start, slc.stop, step)),)
-            raise RuntimeError(f"Can't get shape of {self} because source shape "
-                               "is unknown.")
-        return s.shape
+        return self._shaped_inst._set_attrs(self)
 
     def as_array(self, copy=False, flat=True):
         """
@@ -766,17 +664,31 @@ class SliceIndexer(ShapedSliceIndexer):
         """
         return self.shaped_array(copy=copy, flat=flat)
 
+    @property
+    def indexed_src_shape(self):
+        """
+        Return the shape of the result of indexing into the source.
+
+        Returns
+        -------
+        tuple
+            The shape of the index.
+        """
+        slc = self._slice
+        if self._flat_src and slc.start is not None and slc.stop is not None:
+            step = 1 if slc.step is None else slc.step
+            return (len(range(slc.start, slc.stop, step)),)
+        return super().indexed_src_shape
+
 
 class ShapedArrayIndexer(Indexer):
     """
-    Abstract index array class that is 'shaped'.
+    Abstract index array class that knows its source shape.
 
     Parameters
     ----------
     arr : ndarray
         The index array.
-    orig_shape : tuple or None
-        Original shape of the array.
     flat_src : bool
         If True, source is treated as flat.
 
@@ -784,11 +696,9 @@ class ShapedArrayIndexer(Indexer):
     ----------
     _arr : ndarray
         The wrapped index array object.
-    _orig_shape : tuple
-        Original shape of the array.
     """
 
-    def __init__(self, arr, orig_shape=None, flat_src=None):
+    def __init__(self, arr, flat_src=None):
         """
         Initialize attributes.
         """
@@ -801,9 +711,7 @@ class ShapedArrayIndexer(Indexer):
             raise TypeError(f"Can't create an index array using indices of "
                             f"non-integral type '{ndarr.dtype.type.__name__}'.")
 
-        self._orig_shape = ndarr.shape if orig_shape is None else orig_shape
-
-        self._arr = ndarr.flat[:]
+        self._arr = ndarr
 
     def __call__(self):
         """
@@ -814,9 +722,7 @@ class ShapedArrayIndexer(Indexer):
         int
             This index array.
         """
-        v = self._arr.view()
-        v.shape = self._orig_shape
-        return v
+        return self._arr
 
     def __str__(self):
         """
@@ -827,7 +733,7 @@ class ShapedArrayIndexer(Indexer):
         str
             String representation.
         """
-        return _truncate(f"{self()}".replace('\n', ''))
+        return _truncate(f"{self._arr}".replace('\n', ''))
 
     def copy(self):
         """
@@ -841,16 +747,16 @@ class ShapedArrayIndexer(Indexer):
         return super().copy(self._arr)
 
     @property
-    def shape(self):
+    def min_src_dim(self):
         """
-        Return the shape of the indices.
+        Return the number of source dimensions.
 
         Returns
         -------
-        tuple
-            The shape of the indices.
+        int
+            The number of dimensions expected in the source array.
         """
-        return self._orig_shape
+        return 1
 
     def as_array(self, copy=False, flat=True):
         """
@@ -869,10 +775,9 @@ class ShapedArrayIndexer(Indexer):
             The index array.
         """
         if flat:
-            arr = self._arr
+            arr = self._arr.ravel()
         else:
-            arr = self._arr.view()
-            arr.shape = self._orig_shape
+            arr = self._arr
         if copy:
             return arr.copy()
         return arr
@@ -892,8 +797,8 @@ class ShapedArrayIndexer(Indexer):
             The index into a flat array.
         """
         if copy:
-            return self._arr.copy()
-        return self._arr
+            return self._arr.ravel().copy()
+        return self._arr.ravel()
 
     def _check_bounds(self):
         """
@@ -933,8 +838,6 @@ class ArrayIndexer(ShapedArrayIndexer):
     ----------
     arr : ndarray
         The index array.
-    orig_shape : tuple or None
-        Original shape of the array.
     flat_src : bool or None
         If True, treat source as flat.
     """
@@ -951,20 +854,31 @@ class ArrayIndexer(ShapedArrayIndexer):
         if self._shaped_inst is not None:
             return self._shaped_inst
 
+        if self._src_shape is None:
+            return None
+
         negs = self._arr < 0
         if np.any(negs):
-            if self._src_shape is None:
-                return None
-            else:
-                sharr = self._arr.copy()
-                sharr[negs] += self._src_shape[0]
+            sharr = self._arr.copy()
+            sharr[negs] += self._src_shape[0]
         else:
             sharr = self._arr
 
-        self._shaped_inst = ShapedArrayIndexer(sharr, orig_shape=self._orig_shape)
-
+        self._shaped_inst = ShapedArrayIndexer(sharr)
         return self._shaped_inst._set_attrs(self)
 
+    @property
+    def indexed_src_shape(self):
+        """
+        Return the shape of the result of indexing into the source.
+
+        Returns
+        -------
+        tuple
+            The shape of the index.
+        """
+        return self._arr.shape
+
 
 class ShapedMultiIndexer(Indexer):
     """
@@ -974,8 +888,6 @@ class ShapedMultiIndexer(Indexer):
     ----------
     tup : tuple
         Tuple of indices/slices.
-    orig_shape : tuple or None
-        The original shape of the array.
     flat_src : bool
         If True, treat source array as flat.
 
@@ -983,23 +895,28 @@ class ShapedMultiIndexer(Indexer):
     ----------
     _tup : tuple
         The wrapped tuple of indices/slices.
-    _orig_shape : tuple
-        Original shape.
     _idx_list : list
         List of Indexers.
     """
 
-    def __init__(self, tup, orig_shape=None, flat_src=None):
+    def __init__(self, tup, flat_src=False):
         """
         Initialize attributes.
         """
+        if flat_src and len(tup) > 1:
+            raise RuntimeError(f"Can't index into a flat array with an indexer expecting {len(tup)}"
+                               " dimensions.")
         super().__init__(flat_src)
         self._tup = tup
-        self._orig_shape = orig_shape
         self._set_idx_list()
 
     def _set_idx_list(self):
-        self._idx_list = [indexer(i, flat=self._flat_src) for i in self._tup]
+        self._idx_list = []
+        for i in self._tup:
+            if isinstance(i, (np.ndarray, list)):  # need special handling here for ndim > 1 arrays
+                self._idx_list.append(ArrayIndexer(i, flat_src=self._flat_src))
+            else:
+                self._idx_list.append(indexer(i, flat_src=self._flat_src))
 
     def __call__(self):
         """
@@ -1021,7 +938,7 @@ class ShapedMultiIndexer(Indexer):
         str
             String representation.
         """
-        return f"{self._tup}".strip('\n')
+        return str(self._tup)
 
     def copy(self):
         """
@@ -1035,30 +952,7 @@ class ShapedMultiIndexer(Indexer):
         return super().copy(self._tup)
 
     @property
-    def shape(self):
-        """
-        Return the shape of the indices.
-
-        Returns
-        -------
-        tuple
-            The shape of the indices.
-        """
-        lens = []
-        seen_arr = False
-        for i in self._idx_list:
-            if isinstance(i, ShapedSliceIndexer):
-                lens.append(len(i))
-            elif isinstance(i, ShapedArrayIndexer) and not seen_arr:
-                # only first array idx counts toward shape
-                lens.append(len(i))
-                seen_arr = True
-            # int indexers don't count toward shape (scalar array has shape ())
-
-        return tuple(lens)
-
-    @property
-    def src_ndim(self):
+    def min_src_dim(self):
         """
         Return the number of source dimensions.
 
@@ -1085,20 +979,15 @@ class ShapedMultiIndexer(Indexer):
         ndarray
             The index array into a flat array.
         """
-        # return as a flattened index array into a flat source
         if self._src_shape is None:
             raise ValueError(f"Can't determine extent of array because source shape is not known.")
 
         idxs = np.arange(np.product(self._src_shape), dtype=np.int32).reshape(self._src_shape)
 
-        # TODO: add different behavior here for flat/nonflat
         if flat:
             return idxs[self()].ravel()
         else:
-            if self._orig_shape is None:
-                return idxs[self()]
-            else:
-                return idxs[self()].reshape(self._orig_shape)
+            return idxs[self()]
 
     def flat(self, copy=False):
         """
@@ -1132,7 +1021,7 @@ class ShapedMultiIndexer(Indexer):
         Indexer
             Self is returned to allow chaining.
         """
-        self._check_src_shape(shape)
+        self._check_src_shape(shape2tuple(shape))
         super().set_src_shape(shape, dist_shape)
         if shape is None:
             return self
@@ -1147,9 +1036,9 @@ class ShapedMultiIndexer(Indexer):
         return self
 
     def _check_src_shape(self, shape):
-        if shape is not None and len(shape) != len(self._idx_list):
+        if shape is not None and not self._flat_src and len(shape) < len(self._idx_list):
             raise ValueError(f"Can't set source shape to {shape} because indexer {self} expects "
-                             f"{self.src_ndim} dimensions.")
+                             f"{len(self._idx_list)} dimensions.")
 
     def _check_bounds(self):
         """
@@ -1170,9 +1059,6 @@ class ShapedMultiIndexer(Indexer):
         """
         return self.as_array().tolist()
 
-    def _appears_flat(self):
-        return False
-
 
 class MultiIndexer(ShapedMultiIndexer):
     """
@@ -1182,8 +1068,6 @@ class MultiIndexer(ShapedMultiIndexer):
     ----------
     tup : tuple
         Tuple of indices/slices.
-    orig_shape : tuple or None
-        The original shape of the array.
     flat_src : bool
         If True, treat source array as flat.
     """
@@ -1200,18 +1084,20 @@ class MultiIndexer(ShapedMultiIndexer):
         if self._shaped_inst is not None:
             return self._shaped_inst
 
+        if self._src_shape is None:
+            return None
+
         try:
             self._shaped_inst = ShapedMultiIndexer(tuple(idxer.shaped_instance()()
                                                          for idxer in self._idx_list),
                                                    flat_src=self._flat_src)
         except Exception as err:
             self._shaped_inst = None
-            return
-
-        if self._src_shape is not None:
+        else:
             self._shaped_inst.set_src_shape(self._src_shape)
+            self._shaped_inst._set_attrs(self)
 
-        return self._shaped_inst._set_attrs(self)
+        return self._shaped_inst
 
 
 class EllipsisIndexer(Indexer):
@@ -1236,7 +1122,13 @@ class EllipsisIndexer(Indexer):
         Initialize attributes.
         """
         super().__init__(flat_src)
-        self._tup = tup
+        tlist = []
+        # convert any internal lists/tuples to arrays
+        for i, v in enumerate(tup):
+            if isinstance(v, (list, tuple)):
+                v = np.atleast_1d(v)
+            tlist.append(v)
+        self._tup = tuple(tlist)
 
     def __call__(self):
         """
@@ -1272,7 +1164,7 @@ class EllipsisIndexer(Indexer):
         return super().copy(self._tup)
 
     @property
-    def src_ndim(self):
+    def min_src_dim(self):
         """
         Return the number of source dimensions.
 
@@ -1281,15 +1173,8 @@ class EllipsisIndexer(Indexer):
         int
             The number of dimensions expected in the source array.
         """
-        if self._flat_src:
-            return 1
-
-        if self._shaped_inst is None:
-            s = self.shaped_instance()
-            if s is None:
-                raise ValueError(f"Can't get ndim of {self} because it has no source shape.")
-
-        return self._shaped_inst.src_ndim
+        mn = len(self._tup) - 1
+        return mn if mn > 1 else 1
 
     def shaped_instance(self):
         """
@@ -1322,6 +1207,7 @@ class EllipsisIndexer(Indexer):
             idxer = indexer(lst[0])
         else:
             idxer = indexer(tuple(lst))
+
         idxer.set_src_shape(self._src_shape)
         self._shaped_inst = idxer.shaped_instance()
         return self._shaped_inst._set_attrs(self)
@@ -1379,214 +1265,13 @@ class EllipsisIndexer(Indexer):
         """
         return self.as_array().tolist()
 
-    def _appears_flat(self):
-        return False
-
-
-# the following class will go away when we drop support for our custom non-flat indexing format
-class ListOfTuplesArrayIndexer(Indexer):
-    """
-    Multi indexer using our custom 'list of tuples' format.
-
-    Parameters
-    ----------
-    tup : tuple
-        Tuple of indices/slices.
-    flat_src : bool
-        If True, source is treated as flat.
-
-    Attributes
-    ----------
-    _arr : ndarray
-        Multidimensional index array.
-    _flat_src : bool
-        If True, index is into a flat source array.
-    _npy_inds : tuple
-        Tuple containing the equivalent numpy compatible index arrays.
-    """
-
-    def __init__(self, tup, flat_src=None):
-        """
-        Initialize attributes.
-        """
-        tup = np.atleast_1d(tup)
-        self._arr = tup
-
-        orig_shape = tup.shape[:-1]
-        ndims = tup.shape[-1]
-        size = np.product(orig_shape)
-        totsize = size * ndims
-        self._npy_inds = tuple(tup.flat[i:totsize:ndims] for i in range(ndims))
-        super().__init__(flat_src)
-
-    def __str__(self):
-        """
-        Return string representation.
-
-        Returns
-        -------
-        str
-            String representation.
-        """
-        return _truncate(f"{self._arr}".replace('\n', ''))
-
-    def __call__(self):
-        """
-        Return this multidimensional index as a valid numpy array index.
-
-        Returns
-        -------
-        int
-            This multidimensional index.
-        """
-        return self._npy_inds
-
-    @property
-    def src_ndim(self):
-        """
-        Return the number of source dimensions.
-
-        Returns
-        -------
-        int
-            The number of dimensions expected in the source array.
-        """
-        return self._arr.shape[-1]
-
-    @property
-    def shape(self):
-        """
-        Return the shape of the indices.
-
-        Returns
-        -------
-        tuple
-            The shape of the indices.
-        """
-        return self._arr.shape[:-1]
-
-    def copy(self):
-        """
-        Copy this Indexer.
-
-        Returns
-        -------
-        Indexer
-            A copy of this Indexer.
-        """
-        return super().copy(self._arr)
-
-    def flat(self, copy=False):
-        """
-        Return an index array into a flat array.
-
-        Parameters
-        ----------
-        copy : bool
-            If True, make sure the array returned is a copy.
-
-        Returns
-        -------
-        ndarray
-            An index array into a flat array.
-        """
-        return self.shaped_array(copy=copy, flat=True)
-
-    def set_src_shape(self, shape, dist_shape=None):
-        """
-        Set the shape of the 'source' array .
-
-        Parameters
-        ----------
-        shape : tuple or int
-            The shape of the 'source' array.
-        dist_shape : tuple or None
-            If not None, the full distributed shape of the source.
-
-        Returns
-        -------
-        Indexer
-            Self is returned to allow chaining.
-        """
-        if shape is not None and len(shape) != self.src_ndim:
-            raise ValueError(f"Can't set source shape to {shape} because indexer {self} expects "
-                             f"{self.src_ndim} dimensions.")
-
-        return super().set_src_shape(shape, dist_shape)
-
-    def _check_bounds(self):
-        """
-        Check that indices are within the bounds of the source shape.
-        """
-        if self._src_shape is not None:
-            for inds, s in zip(self._npy_inds, self._dist_shape):
-                if np.any(inds >= s):
-                    raise RuntimeError(f"Indexer {self} exceeds bounds for axis of dimension {s}.")
-                negs = inds[inds < 0]
-                if negs.size > 0 and np.any(negs < -s):
-                    raise RuntimeError(f"Indexer {self} exceeds bounds for axis of dimension {s}.")
-
-    def shaped_instance(self):
-        """
-        Return a 'shaped' version of this Indexer type.
-
-        Returns
-        -------
-        ShapedMultiIndexer or None
-            Will return a ShapedMultiIndexer if possible, else None.
-        """
-        if self._shaped_inst is not None:
-            return self._shaped_inst
-
-        try:
-            self._shaped_inst = ShapedMultiIndexer(self._npy_inds, self.shape)
-        except Exception:
-            self._shaped_inst = None
-
-        if self._src_shape is not None:
-            self._shaped_inst.set_src_shape(self._src_shape)
-
-        return self._shaped_inst._set_attrs(self)
-
-    def as_array(self, copy=False, flat=True):
-        """
-        Return an index array into a flat array.
-
-        Parameters
-        ----------
-        copy : bool
-            If True, make sure the array returned is a copy.
-        flat : bool
-            If True, return a flat array.
-
-        Returns
-        -------
-        ndarray
-            The index array.
-        """
-        return self.shaped_array(copy=copy, flat=flat)
-
-    def to_json(self):
-        """
-        Return a JSON serializable version of self.
-
-        Returns
-        -------
-        list of int or int
-            List or int version of self.
-        """
-        return self.as_array().tolist()
-
-    def _appears_flat(self):
-        return len(self._npy_inds) == 1
-
 
 class IndexMaker(object):
     """
     A Factory for Indexer objects.
     """
 
-    def __call__(self, idx, src_shape=None, flat=None, new_style=True):
+    def __call__(self, idx, src_shape=None, flat_src=False):
         """
         Return an Indexer instance based on the passed indices/slices.
 
@@ -1596,10 +1281,8 @@ class IndexMaker(object):
             Some sort of index/indices/slice.
         src_shape : tuple or None
             Source shape if known.
-        flat : bool or None
+        flat_src : bool
             If True, indices are into a flat source.
-        new_style : bool
-            If True, indexer follows behavior of numpy indexing.
 
         Returns
         -------
@@ -1607,39 +1290,37 @@ class IndexMaker(object):
             The Indexer instance we created based on the args.
         """
         if idx is ...:
-            idxer = EllipsisIndexer((idx,), flat_src=flat)
+            idxer = EllipsisIndexer((idx,), flat_src=flat_src)
         elif isinstance(idx, int):
-            idxer = IntIndexer(idx, flat_src=flat)
+            idxer = IntIndexer(idx, flat_src=flat_src)
         elif isinstance(idx, slice):
-            idxer = SliceIndexer(idx, flat_src=flat)
+            idxer = SliceIndexer(idx, flat_src=flat_src)
 
         elif isinstance(idx, tuple):
-            if idx and not new_style:
-                mat = np.atleast_1d(idx)
-                if mat.dtype == int and mat.ndim == 1:
-                    idxer = ArrayIndexer(mat, flat_src=flat)
-                else:
-                    idxer = ListOfTuplesArrayIndexer(mat, flat_src=flat)
+            multi = len(idx) > 1
+            for i in idx:
+                if i is ...:
+                    multi = len(idx) > 2  # ... doesn't count toward limit of dimensions
+                    idxer = EllipsisIndexer(idx, flat_src=flat_src)
+                    break
             else:
-                multi = len(idx) > 1
-                for i in idx:
-                    if i is ...:
-                        multi = len(idx) > 2  # ... doesn't count toward limit of dimensions
-                        idxer = EllipsisIndexer(idx, flat_src=flat)
-                        break
-                else:
-                    idxer = MultiIndexer(idx, flat_src=flat)
-                if flat and multi:
-                    raise RuntimeError("Can't use multdimensional index into a flat source.")
+                idxer = MultiIndexer(idx, flat_src=flat_src)
+            if flat_src and multi:
+                raise RuntimeError("Can't use a multdimensional index into a flat source.")
         else:
             arr = np.atleast_1d(idx)
-            if flat or new_style or arr.ndim == 1:
-                idxer = ArrayIndexer(arr, flat_src=flat)
+            if arr.ndim == 1:
+                idxer = ArrayIndexer(arr, flat_src=flat_src)
             else:
-                idxer = ListOfTuplesArrayIndexer(arr, flat_src=flat)
+                issue_warning("Using a non-tuple sequence for multidimensional indexing is "
+                              "deprecated; use `arr[tuple(seq)]` instead of `arr[seq]`. In the "
+                              "future this will be interpreted as an array index, "
+                              "`arr[np.array(seq)]`, which will result either in an error or a "
+                              "different result.")
+                idxer = MultiIndexer(tuple(idx), flat_src=flat_src)
 
         if src_shape is not None:
-            if flat:
+            if flat_src:
                 src_shape = (np.product(src_shape),)
             idxer.set_src_shape(src_shape)
 
@@ -1665,26 +1346,108 @@ class IndexMaker(object):
 indexer = IndexMaker()
 
 
-def to_numpy_style(inds):
+def _convert_ellipsis_idx(shape, idx):
+    lst = [None] * len(shape)
+    # number of full slice dimensions
+    nfull = len(shape) - len(idx) + 1
+    i = 0
+    for ind in idx:
+        if ind is ...:
+            for j in range(nfull):
+                lst[i] = slice(None)
+                i += 1
+        else:
+            lst[i] = ind
+            i += 1
+
+    return tuple(lst)
+
+
+class resolve_shape(object):
     """
-    Convert old style OpenMDAO-specific indices into numpy-like indices.
+    Class that computes the result shape from a source shape and an index.
 
     Parameters
     ----------
-    inds : list of tuples
-        Old style indices.
+    shape : tuple
+        The shape of the source.
 
-    Returns
-    -------
-    tuple of ndarrays
-        New style indices.
+    Attributes
+    ----------
+    _shape : tuple
+        The shape of the source.
     """
-    inds = indexer(inds, new_style=False)
-    if isinstance(inds, ListOfTuplesArrayIndexer):
-        return tuple(i.tolist() for i in inds._npy_inds)
-    elif isinstance(inds, ShapedArrayIndexer):
-        return inds().tolist()
-    raise TypeError("Indices are not old-style format.")
+
+    def __init__(self, shape):
+        """
+        Initialize attributes.
+
+        Parameters
+        ----------
+        shape : tuple or int
+            Shape of the source.
+        """
+        self._shape = shape2tuple(shape)
+
+    def __getitem__(self, idx):
+        """
+        Return the shape of the result of indexing into the source with index idx.
+
+        Parameters
+        ----------
+        idx : int, slice, tuple, ndarray
+            The index into the source.
+
+        Returns
+        -------
+        tuple
+            The shape after indexing.
+        """
+        if not isinstance(idx, tuple):
+            idx = (idx,)
+            is_tup = False
+        else:
+            is_tup = True
+
+        for i in idx:
+            if i is ...:
+                idx = _convert_ellipsis_idx(self._shape, idx)
+                break
+
+        if len(self._shape) < len(idx):
+            raise ValueError(f"Index {idx} dimension too large to index into shape {self._shape}.")
+
+        lens = []
+        seen_arr = False
+        arr_shape = None  # to handle multi-indexing where individual sub-arrays have a shape
+        for dim, ind in zip_longest(self._shape, idx):
+            if ind is None:
+                lens.append(dim)
+            elif isinstance(ind, slice):
+                lens.append(len(range(*ind.indices(dim))))
+            elif isinstance(ind, np.ndarray):
+                if not seen_arr:
+                    seen_arr = True
+                    if ind.ndim > 1:
+                        if arr_shape is not None and arr_shape != ind.shape:
+                            raise ValueError("Multi-index has index sub-arrays of different shapes "
+                                             f"({arr_shape} != {ind.shape}).")
+                        arr_shape = ind.shape
+                    else:
+                        # only first array idx counts toward shape
+                        lens.append(ind.size)
+            # int indexers don't count toward shape (scalar array has shape ())
+            elif not isinstance(ind, Integral):
+                raise TypeError(f"Index {ind} of type '{type(ind).__name__}' is invalid.")
+
+        if arr_shape is not None:
+            return arr_shape
+
+        if is_tup or len(lens) >= 1:
+            return tuple(lens)
+        elif is_tup:
+            return ()
+        return (1,)
 
 
 # Since this is already user facing we'll leave it as is, and just use the output of
@@ -1713,18 +1476,3 @@ class Slicer(object):
 
 # instance of the Slicer class to be used by users
 slicer = Slicer()
-
-
-# TODO: remove this when the 'new_style' src_indices arg is removed
-def _update_new_style(src_indices, new_style, prefix=""):
-    if not new_style:
-        if isinstance(src_indices, tuple):
-            for part in src_indices:
-                if part is ... or isinstance(part, slice):
-                    return True
-            warn_deprecation(f"{prefix}: 'src_indices={src_indices}' is specified in"
-                             " a deprecated format. In a future release, 'src_indices'"
-                             " will be expected to use NumPy array indexing, so replace the "
-                             f"existing src_indices with {to_numpy_style(src_indices)}.")
-
-    return new_style
