@@ -1,9 +1,15 @@
 """Define the OptionsDictionary class."""
 
+import re
+
 from openmdao.utils.om_warnings import warn_deprecation
 from openmdao.core.constants import _UNDEFINED
 
 
+# regex to check for valid names.
+namecheck_rgx = re.compile('[a-zA-Z][_a-zA-Z0-9]*')
+
+
 #
 # Template for `check_valid` function
 #
@@ -14,14 +20,14 @@ def check_valid(name, value):
     Parameters
     ----------
     name : str
-        name of the option
+        Name of the option.
     value : any
-        value for the option
+        Value for the option.
 
     Raises
     ------
     ValueError
-        if value is not valid for option
+        If value is not valid for option.
     """
     raise ValueError(f"Option '{name}' with value {value} is not valid.")
 
@@ -35,6 +41,13 @@ class OptionsDictionary(object):
         2. the supports attribute in drivers
         3. the options attribute in systems
 
+    Parameters
+    ----------
+    parent_name : str
+        Name or class name of System that owns this OptionsDictionary.
+    read_only : bool
+        If True, setting (via __setitem__ or update) is not permitted.
+
     Attributes
     ----------
     _dict : dict of dict
@@ -46,29 +59,17 @@ class OptionsDictionary(object):
         If True, no options can be set after declaration.
     _all_recordable : bool
         Flag to determine if all options in UserOptions are recordable.
-    _deprecation_warning_issued : list
-        Option names that are deprecated and a warning has been issued for their use.
     """
 
     def __init__(self, parent_name=None, read_only=False):
         """
         Initialize all attributes.
-
-        Parameters
-        ----------
-        parent_name : str
-            Name or class name of System that owns this OptionsDictionary
-        read_only : bool
-            If True, setting (via __setitem__ or update) is not permitted.
         """
         self._dict = {}
         self._parent_name = parent_name
         self._read_only = read_only
-
         self._all_recordable = True
 
-        self._deprecation_warning_issued = []
-
     def __getstate__(self):
         """
         Return state as a dict.
@@ -162,7 +163,8 @@ class OptionsDictionary(object):
 
             deprecation = options['deprecation']
             if deprecation is not None:
-                tlist.append([key, default, acceptable_values, acceptable_types, desc, deprecation])
+                tlist.append([key, default, acceptable_values, acceptable_types, desc,
+                              deprecation[0]])
             else:
                 tlist.append([key, default, acceptable_values, acceptable_types, desc])
 
@@ -319,21 +321,29 @@ class OptionsDictionary(object):
         allow_none : bool
             If True, allow None as a value regardless of values or types.
         recordable : bool
-            If True, add to recorder
-        deprecation : str or None
+            If True, add to recorder.
+        deprecation : str or tuple or None
             If None, it is not deprecated. If a str, use as a DeprecationWarning
-            during __setitem__ and __getitem__
+            during __setitem__ and __getitem__.  If a tuple of the form (msg, new_name),
+            display msg as with str, and forward any __setitem__/__getitem__ to new_name.
         """
+        match = namecheck_rgx.match(name)
+        if match is None or match.group() != name:
+            warn_deprecation(f"'{name}' is not a valid python name and will become an invalid "
+                             "option name in a future release. You can prevent this warning (and "
+                             "future exceptions) by declaring this option using a valid python "
+                             "name.")
+
         if values is not None and not isinstance(values, (set, list, tuple)):
-            self._raise("In declaration of option '%s', the 'values' arg must be of type None,"
-                        " list, or tuple - not %s." % (name, values), exc_type=TypeError)
+            self._raise(f"In declaration of option '{name}', the 'values' arg must be of type None,"
+                        f" list, or tuple - not {values}.", exc_type=TypeError)
 
         if types is not None and not isinstance(types, (type, set, list, tuple)):
-            self._raise("In declaration of option '%s', the 'types' arg must be None, a type "
-                        "or a tuple - not %s." % (name, types), exc_type=TypeError)
+            self._raise(f"In declaration of option '{name}', the 'types' arg must be None, a type "
+                        f"or a tuple - not {types}.", exc_type=TypeError)
 
         if types is not None and values is not None:
-            self._raise("'types' and 'values' were both specified for option '%s'." % name)
+            self._raise(f"'types' and 'values' were both specified for option '{name}'.")
 
         if types is bool:
             values = (True, False)
@@ -347,6 +357,18 @@ class OptionsDictionary(object):
             # specifying default=None implies allow_none
             allow_none = True
 
+        alias = None
+        if deprecation is not None:
+            if isinstance(deprecation, (list, tuple)):
+                if len(deprecation) != 2:
+                    self._raise("deprecation must be None, str, or a tuple or list containing "
+                                "(str, str).", RuntimeError)
+                dep, alias = deprecation
+                # [message, alias, display warning (becomes False after first display)]
+                deprecation = [dep, alias, True]
+            else:
+                deprecation = [deprecation, None, True]
+
         self._dict[name] = {
             'val': default,
             'values': values,
@@ -373,7 +395,6 @@ class OptionsDictionary(object):
         ----------
         name : str
             The name of a key, the entry of which will be removed from the internal dictionary.
-
         """
         if name in self._dict:
             del self._dict[name]
@@ -412,7 +433,7 @@ class OptionsDictionary(object):
 
         Returns
         -------
-        boolean
+        bool
             whether key is in the local dict.
         """
         return key in self._dict
@@ -431,16 +452,15 @@ class OptionsDictionary(object):
         try:
             meta = self._dict[name]
         except KeyError:
-            # The key must have been declared.
-            msg = "Option '{}' cannot be set because it has not been declared."
-            self._raise(msg.format(name), exc_type=KeyError)
-
-        if meta['deprecation'] is not None and name not in self._deprecation_warning_issued:
-            warn_deprecation(meta['deprecation'])
-            self._deprecation_warning_issued.append(name)
+            # The key must not have been declared.
+            self._raise(f"Option '{name}' cannot be set because it has not been declared.",
+                        exc_type=KeyError)
 
         if self._read_only:
-            self._raise("Tried to set read-only option '{}'.".format(name), exc_type=KeyError)
+            self._raise(f"Tried to set read-only option '{name}'.", exc_type=KeyError)
+
+        if meta['deprecation'] is not None:
+            name, meta = self._handle_deprecation(name, meta)
 
         self._assert_valid(name, value)
 
@@ -464,22 +484,64 @@ class OptionsDictionary(object):
         # If the option has been set in this system, return the set value
         try:
             meta = self._dict[name]
-            if meta['deprecation'] is not None and name not in self._deprecation_warning_issued:
-                warn_deprecation(meta['deprecation'])
-                self._deprecation_warning_issued.append(name)
-            if meta['has_been_set']:
-                return meta['val']
-            else:
-                self._raise("Option '{}' is required but has not been set.".format(name))
         except KeyError:
-            self._raise("Option '{}' cannot be found".format(name), exc_type=KeyError)
+            self._raise(f"Option '{name}' has not been declared.", exc_type=KeyError)
+
+        if meta['deprecation'] is not None:
+            name, meta = self._handle_deprecation(name, meta)
+
+        if meta['has_been_set']:
+            return meta['val']
+        else:
+            self._raise(f"Option '{name}' is required but has not been set.")
 
     def items(self):
         """
         Yield name and value of options.
+
+        Yields
+        ------
+        key : str
+            Name of option.
+        value : int or bool or float or string
+            Value of the option.
         """
         for key, val in self._dict.items():
-            if 'val' in val:
+            try:
                 yield key, val['val']
-            elif 'value' in val:
+            except KeyError:
                 yield key, val['value']
+
+    def _handle_deprecation(self, name, meta):
+        """
+        Update the warning counter and do name translation of deprecated variable if needed.
+
+        Parameters
+        ----------
+        name : str
+            Name of the deprecated variable.
+        meta : dict
+            Metadata dictionary corresponding to the deprecated variable.
+
+        Returns
+        -------
+        str
+            The variable name, updated to the non-deprecated name if found.
+        dict
+            Metadata dictionary corresponding to either the original variable or to the
+            non-deprecated varsion if found.
+        """
+        msg, alias, show_warn = meta['deprecation']
+        if show_warn:
+            warn_deprecation(msg)
+            meta['deprecation'][2] = False  # turn off future warnings for this variable
+
+        if alias:
+            try:
+                meta = self._dict[alias]
+            except KeyError:
+                msg = f"Can't find aliased option '{alias}' for deprecated option '{name}'."
+                self._raise(msg, exc_type=KeyError)
+            name = alias
+
+        return name, meta
