@@ -2,12 +2,9 @@
 Support functions for the 'openmdao scaffold' command.
 """
 
-import sys
 import os
 from pprint import pformat
 
-from openmdao.utils.general_utils import simple_warning
-
 
 _common_bases = {
     'ExplicitComponent': 'openmdao_component',
@@ -134,8 +131,8 @@ def _scaffold_exec(options, user_args):
 
                 setup_dict = {
                     'name': dist_name,
-                    'version': '???',
-                    'description': '???',
+                    'version': '0.0.1',
+                    'description': '',
                     'keywords': keywords,
                     'license': '???',
                     'packages': [pkg_name, pkg_name + '.' + 'test'],
