@@ -661,7 +661,7 @@ def add_unit(name, unit, comment=''):
     if comment:
         _UNIT_LIB.help.append((name, comment, unit))
     if isinstance(unit, str):
-        unit = eval(unit, {'__builtins__': None, 'pi': pi},
+        unit = eval(unit, {'__builtins__': None, 'pi': pi},  # nosec: scope limited
                     _UNIT_LIB.unit_table)
     unit.set_name(name)
     if name in _UNIT_LIB.unit_table:
@@ -768,7 +768,7 @@ def update_library(filename):
     filename : str or file
         Source of units configuration data.
     """
-    if isinstance(filename, basestring):
+    if isinstance(filename, str):
         inp = open(filename, 'rU')
     else:
         inp = filename
@@ -879,7 +879,8 @@ def _find_unit(unit, error=False):
             unit = _UNIT_CACHE[name]
         except KeyError:
             try:
-                unit = eval(name, {'__builtins__': None}, _UNIT_LIB.unit_table)
+                unit = eval(name, {'__builtins__': None},  # nosec: scope limited
+                            _UNIT_LIB.unit_table)
             except Exception:
 
                 # This unit might include prefixed units that aren't in the
@@ -896,7 +897,7 @@ def _find_unit(unit, error=False):
                     # check if this was a compound unit, so each
                     # substring might be a unit
                     try:
-                        eval(item, {'__builtins__': None},
+                        eval(item, {'__builtins__': None},  # nosec: scope limited
                              _UNIT_LIB.unit_table)
 
                     except Exception:  # maybe is a prefixed unit then
@@ -920,7 +921,8 @@ def _find_unit(unit, error=False):
                                 raise ValueError(f"The units '{name}' are invalid.")
                             return None
 
-                unit = eval(name, {'__builtins__': None}, _UNIT_LIB.unit_table)
+                unit = eval(name, {'__builtins__': None},  # nosec: scope limited
+                            _UNIT_LIB.unit_table)
 
             _UNIT_CACHE[name] = unit
     else:
