@@ -18,13 +18,12 @@ class N2Layout {
      * @param {boolean} showLinearSolverNames Whether to show linear or non-linear solver names.
      * @param {Object} dims The initial sizes for multiple tree elements.
      */
-    constructor(model, newZoomedElement, showLinearSolverNames, dims) {
+    constructor(model, newZoomedElement, showLinearSolverNames, showSolvers, dims) {
         this.model = model;
 
         this.zoomedElement = newZoomedElement;
         this.showLinearSolverNames = showLinearSolverNames;
 
-        this.outputNamingType = "Absolute";
         this.zoomedNodes = [];
         this.visibleNodes = [];
 
@@ -33,6 +32,8 @@ class N2Layout {
         this.curVisibleNodeCount = 0;
         this.prevVisibleNodeCount = 0;
 
+        this.showSolvers = showSolvers ;
+
         // Initial size values derived from read-only defaults
         this.size = dims.size;
         this.svg = d3.select("#svgId");
@@ -46,18 +47,17 @@ class N2Layout {
         this._updateTextWidths();
         stopTimer('N2Layout._updateTextWidths');
 
-        startTimer('N2Layout._updateSolverTextWidths');
-        this._updateSolverTextWidths();
-        stopTimer('N2Layout._updateSolverTextWidths');
         delete (this.textRenderer);
 
         startTimer('N2Layout._computeColumnWidths');
         this._computeColumnWidths();
         stopTimer('N2Layout._computeColumnWidths');
 
-        startTimer('N2Layout._computeSolverColumnWidths');
-        this._computeSolverColumnWidths();
-        stopTimer('N2Layout._computeSolverColumnWidths');
+        if (this.showSolvers) {
+            startTimer('N2Layout._computeSolverColumnWidths');
+            this._computeSolverColumnWidths();
+            stopTimer('N2Layout._computeSolverColumnWidths');
+        }
 
         startTimer('N2Layout._setColumnLocations');
         this._setColumnLocations();
@@ -69,12 +69,13 @@ class N2Layout {
         if (this.zoomedElement.parent)
             this.zoomedNodes.push(this.zoomedElement.parent);
 
-        startTimer('N2Layout._computeSolverNormalizedPositions');
-        this._computeSolverNormalizedPositions(this.model.root, 0, false, null);
-        stopTimer('N2Layout._computeSolverNormalizedPositions');
-        if (this.zoomedElement.parent)
-            this.zoomedSolverNodes.push(this.zoomedElement.parent);
-
+        if (this.showSolvers) {
+            startTimer('N2Layout._computeSolverNormalizedPositions');
+            this._computeSolverNormalizedPositions(this.model.root, 0, false, null);
+            stopTimer('N2Layout._computeSolverNormalizedPositions');
+            if (this.zoomedElement.parent)
+                this.zoomedSolverNodes.push(this.zoomedElement.parent);
+        }
         this.setTransitionPermission();
 
     }
@@ -165,11 +166,11 @@ class N2Layout {
 
         let retVal = node.name;
 
-        if (this.outputNamingType == "Promoted" &&
-            node.isInputOrOutput() &&
-            this.zoomedElement.propExists('promotions') &&
-            this.zoomedElement.promotions.propExists(node.absPathName)) {
-            retVal = this.zoomedElement.promotions[node.absPathName];
+        if (node.name == '_auto_ivc') {
+            retVal = 'Auto-IVC';
+        }
+        else if (node.absPathName.match(/^_auto_ivc.*/) && node.promotedName !== undefined) {
+            retVal = node.promotedName;
         }
 
         return retVal;
@@ -203,6 +204,11 @@ class N2Layout {
         node.nameWidthPx = this._getTextWidth(this.getText(node)) + 2 *
             this.size.rightTextMargin;
 
+        if (!node.isInputOrOutput()) {
+            node.nameSolverWidthPx = this._getTextWidth(this.getSolverText(node)) + 2 *
+                this.size.rightTextMargin;
+        }
+
         if (node.hasChildren() && !node.isMinimized) {
             for (let child of node.children) {
                 this._updateTextWidths(child);
@@ -211,33 +217,18 @@ class N2Layout {
     }
 
     /**
-     * Determine text width for this and all decendents if node is a solver.
-     * @param {N2TreeNode} [node = this.zoomedElement] Item to begin looking from.
-     */
-    _updateSolverTextWidths(node = this.zoomedElement) {
-        if (node.isInput() || node.varIsHidden) {
-            return;
-        }
-
-        node.nameSolverWidthPx = this._getTextWidth(this.getSolverText(node)) + 2 *
-            this.size.rightTextMargin;
-
-        if (node.hasChildren() && !node.isMinimized) {
-            for (let child of node.children) {
-                this._updateSolverTextWidths(child);
-            }
-        }
-    }
-
-    /** Recurse through the tree and add up the number of leaves that each
+     * Recurse through the tree and add up the number of leaves that each
      * node has, based on their array of visible children.
      * @param {N2TreeNode} [node = this.model.root] The starting node.
      */
     _computeLeaves(node = this.model.root) {
         node.numLeaves = 0;
 
-        if (! node.varIsHidden) {
-            if (this.model.nodeIds.length > Precollapse.minimumNodes) {
+        if (!node.varIsHidden) {
+            if (node.name == '_auto_ivc' && !node.manuallyExpanded) {
+                node.minimize();
+            }
+            else if (this.model.nodeIds.length > Precollapse.minimumNodes) {
                 node.minimizeIfLarge(this.model.depthCount[node.depth]);
             }
 
@@ -253,7 +244,8 @@ class N2Layout {
         }
     }
 
-    /** For visible nodes with children, choose a column width
+    /**
+     * For visible nodes with children, choose a column width
      * large enough to accomodate the widest label in their column.
      * @param {N2TreeNode} node The item to operate on.
      * @param {string} childrenProp Either 'children' or 'subsystem_children'.
@@ -284,7 +276,8 @@ class N2Layout {
         }
     }
 
-    /** Compute column widths across the model, then adjust ends as needed.
+    /**
+     * Compute column widths across the model, then adjust ends as needed.
      * @param {N2TreeNode} [node = this.zoomedElement] Item to operate on.
      */
     _computeColumnWidths(node = this.zoomedElement) {
@@ -313,7 +306,8 @@ class N2Layout {
         this.cols[this.greatestDepth].width = lastColumnWidth;
     }
 
-    /** Compute solver column widths across the model, then adjust ends as needed.
+    /**
+     * Compute solver column widths across the model, then adjust ends as needed.
      * @param {N2TreeNode} [node = this.zoomedElement] Item to operate on.
      */
     _computeSolverColumnWidths(node = this.zoomedElement) {
@@ -342,9 +336,7 @@ class N2Layout {
         this.solverCols[this.greatestDepth].width = lastColumnWidth;
     }
 
-    /** Set the location of the columns based on the width of the columns
-     * to the left.
-     */
+    /** Set the location of the columns based on the width of the columns to the left. */
     _setColumnLocations() {
         this.size.partitionTree.width = 0;
         this.size.solverTree.width = 0;
@@ -353,8 +345,10 @@ class N2Layout {
             this.cols[depth].location = this.size.partitionTree.width;
             this.size.partitionTree.width += this.cols[depth].width;
 
-            this.solverCols[depth].location = this.size.solverTree.width;
-            this.size.solverTree.width += this.solverCols[depth].width;
+             if (this.showSolvers) {
+                 this.solverCols[depth].location = this.size.solverTree.width;
+                 this.size.solverTree.width += this.solverCols[depth].width;
+             }
         }
 
     }
@@ -523,7 +517,7 @@ class N2Layout {
             .duration(N2TransitionDefaults.duration)
             .delay(transitionStartDelay)
             // Hide the transition waiting animation when it ends:
-            .on('end', function() { dom.waiter.attr('class', 'no-show'); });
+            .on('end', function () { dom.waiter.attr('class', 'no-show'); });
 
         this.transitionStartDelay = N2TransitionDefaults.startDelay;
 
